@@ -156,7 +156,7 @@ class CaseHandler(object):
         """
         order = None
         query_field = name_query.split(":")[0]  # example:status
-        query_term = name_query[name_query.index(":") + 1 :].replace(" ", "")  # example:active
+        query_term = name_query[name_query.index(":") + 1 :].strip()
 
         if query_field == "case" and query_term != "":
             LOG.debug("Case display name query")
@@ -212,13 +212,11 @@ class CaseHandler(object):
 
         if query_field == "user":
             LOG.debug(f"Search for cases with assignee '{query_term}'.")
-            users = self.user_collection.find({"name": {"$regex": query_term, "$options": "i"}})
-            nr_users = sum(
-                1
-                for i in self.user_collection.find(
-                    {"name": {"$regex": query_term, "$options": "i"}}
-                )
-            )
+            query_terms = query_term.split(" ")
+            user_query = {
+                "$and": [{"name": {"$regex": term, "$options": "i"}} for term in query_terms]
+            }
+            users = self.user_collection.find(user_query)
             query["assignees"] = {"$in": [user["email"] for user in users]}
 
         return order
@@ -236,6 +234,7 @@ class CaseHandler(object):
         is_research=False,
         status=None,
         phenotype_terms=False,
+        group=None,
         pinned=False,
         cohort=False,
         name_query=None,
@@ -256,7 +255,9 @@ class CaseHandler(object):
             research_requested(bool)
             is_research(bool)
             status(str)
-            phenotype_terms(bool): Fetch all cases with phenotype terms
+            group(ObjectId): fetch all cases in a named case group
+            cohort(bool): Fetch all cases with cohort tags
+            phenotype_terms(bool): Fetch all cases with phenotype
             pinned(bool): Fetch all cases with pinned variants
             name_query(str): Could be hpo term, HPO-group, user, part of display name,
                              part of inds or part of synopsis
@@ -317,6 +318,9 @@ class CaseHandler(object):
         if cohort:
             query["cohorts"] = {"$exists": True, "$ne": []}
 
+        if group:
+            query["group"] = {"$in": [group]}
+
         if assignee:
             query["assignees"] = {"$in": [assignee]}
 
@@ -380,6 +384,23 @@ class CaseHandler(object):
 
         return self.case_collection.find(query).sort("updated_at", -1)
 
+    def case_ids_from_group_id(self, group_id):
+        """Fetches any cases with given group_id from backend.
+
+        Args:
+            group_id(str): A tag for related cases. A case can belong to several groups.
+
+        Returns:
+            case_ids(list): A list of case _ids
+        """
+
+        return [
+            case["_id"]
+            for case in self.case_collection.find(
+                {"group": {"$elemMatch": {"$eq": group_id}}}, {"_id": 1}
+            )
+        ]
+
     def nr_cases(self, institute_id=None):
         """Return the number of cases
 
@@ -564,6 +585,8 @@ class CaseHandler(object):
 
         old_sanger_variants = self.case_sanger_variants(case_obj["_id"])
 
+        genome_build = str(parsed_case.get("genome_build", 37))
+
         if old_case:
             LOG.info(
                 "Update case id for existing case: %s -> %s",
@@ -621,6 +644,7 @@ class CaseHandler(object):
                     case_obj=case_obj,
                     variant_type=variant_type,
                     category=category,
+                    build=genome_build,
                     rank_threshold=case_obj.get("rank_score_threshold", 5),
                 )
 
@@ -676,10 +700,12 @@ class CaseHandler(object):
             - madeline_info: If there is a new pedigree
             - vcf_files: paths to the new files
             - cnv_report: path to the CNV report file
+            - coverage_qc_report: path to the static coverage and qc report file
             - has_svvariants: If there are new svvariants
             - has_strvariants: If there are new strvariants
             - multiqc: If there's an updated multiqc report location
             - mme_submission: If case was submitted to MatchMaker Exchange
+            - variants_stats: number of variants by type
 
             Args:
                 case_obj(dict): The new case information
@@ -695,7 +721,7 @@ class CaseHandler(object):
 
         updated_at = datetime.datetime.now()
         if keep_date:
-            updated_at = old_case["updated_at"]
+            updated_at = old_case.get("updated_at")
 
         # collect already available info from individuals
         old_individuals = old_case.get("individuals")
@@ -724,6 +750,7 @@ class CaseHandler(object):
                     "analysis_date": case_obj["analysis_date"],
                     "delivery_report": case_obj.get("delivery_report"),
                     "cnv_report": case_obj.get("cnv_report"),
+                    "coverage_qc_report": case_obj.get("coverage_qc_report"),
                     "individuals": case_obj["individuals"],
                     "updated_at": updated_at,
                     "rerun_requested": case_obj.get("rerun_requested", False),
@@ -744,6 +771,7 @@ class CaseHandler(object):
                     "multiqc": case_obj.get("multiqc"),
                     "mme_submission": case_obj.get("mme_submission"),
                     "status": case_obj.get("status"),
+                    "variants_stats": case_obj.get("variants_stats"),
                 },
             },
             return_document=pymongo.ReturnDocument.AFTER,
