@@ -14,7 +14,9 @@ from scout.constants import SPIDEX_HUMAN, CLINSIG_MAP
 
 
 class QueryHandler(object):
-    def build_case_query(self, case_id=None, status=None, older_than=None) -> dict:
+    def build_case_query(
+        self, case_id=None, status=None, older_than=None, analysis_type=[]
+    ) -> dict:
         """Build case query based on case id, status and analysis date
 
         Args:
@@ -22,6 +24,7 @@ class QueryHandler(object):
             status(list): one or more case status
             older_than(int): to select cases older than a number of months
             case_ids(list): a list of case _ids
+            analysis_type(list): a list of type of analysis ["wgs", "wes", "panel"]
 
         Returns:
             case_query(dict): query dictionary
@@ -29,20 +32,25 @@ class QueryHandler(object):
         case_query = {}
         if case_id:
             case_query["_id"] = case_id
-        if status:
-            case_query["status"] = {"$in": list(status)}
+        if analysis_type:
+            case_query["individuals.analysis_type"] = {"$in": analysis_type}
         if older_than:
             older_than_date = datetime.now() - timedelta(weeks=older_than * 4)  # 4 weeks in a month
             case_query["analysis_date"] = {"$lt": older_than_date}
+        if status:
+            case_query["status"] = {"$in": list(status)}
         return case_query
 
-    def delete_variants_query(self, case_id, variants_to_keep=[], min_rank_threshold=None) -> dict:
+    def delete_variants_query(
+        self, case_id, variants_to_keep=[], min_rank_threshold=None, keep_ctg=[]
+    ) -> dict:
         """Build a query to delete variants from a case
 
         Args:
             case_id(str): id of a case
             variants_to_keep(list): a list of variant ids
             min_rank_threshold(int): remove variants with rank lower than this number
+            keep_ctg(list): exclude one of more variants categories from deletion. Example ["cancer", "cancer_sv"]
 
         Return:
             variant_query(dict): query dictionary
@@ -51,10 +59,12 @@ class QueryHandler(object):
         case_subquery = {"case_id": case_id}
 
         # Create query to delete all variants that shouldn't be kept or with rank higher than min_rank_threshold
-        if variants_to_keep or min_rank_threshold:
+        if variants_to_keep or min_rank_threshold or keep_ctg:
             variants_query["$and"] = [case_subquery]
             if variants_to_keep:
                 variants_query["$and"].append({"_id": {"$nin": variants_to_keep}})
+            if keep_ctg:
+                variants_query["$and"].append({"category": {"$nin": keep_ctg}})
             if min_rank_threshold:
                 variants_query["$and"].append({"rank_score": {"$lt": min_rank_threshold}})
         else:
@@ -127,7 +137,14 @@ class QueryHandler(object):
             case_obj = self.case(display_name=similar_case_display_name, institute_id=institute_id)
             if case_obj:
                 LOG.debug("Search for cases similar to %s", case_obj.get("display_name"))
-                similar_cases = self.get_similar_cases(case_obj)
+
+                hpo_terms = []
+                for term in case_obj.get("phenotype_terms", []):
+                    hpo_terms.append(term.get("phenotype_id"))
+
+                similar_cases = (
+                    self.cases_by_phenotype(hpo_terms, case_obj["owner"], case_obj["_id"]) or []
+                )
                 LOG.debug("Similar cases: %s", similar_cases)
                 select_cases = [similar[0] for similar in similar_cases]
             else:
@@ -172,6 +189,7 @@ class QueryHandler(object):
                 'gene_panels': list(str),
                 'mvl_tag": boolean,
                 'decipher": boolean,
+                'hide_dismissed': boolean
             }
 
         Arguments:
@@ -195,18 +213,22 @@ class QueryHandler(object):
             if criterion == "case_id":
                 LOG.debug("Building a mongo query for %s" % case_id)
                 mongo_query["case_id"] = case_id
+                continue
 
-            elif criterion == "variant_ids" and variant_ids:
+            if criterion == "variant_ids" and variant_ids:
                 LOG.debug("Adding variant_ids %s to query" % ", ".join(variant_ids))
                 mongo_query["variant_id"] = {"$in": variant_ids}
+                continue
 
-            elif criterion == "category":
+            if criterion == "category":
                 LOG.debug("Querying category %s" % category)
                 mongo_query["category"] = category
+                continue
 
-            elif criterion == "variant_type":
+            if criterion == "variant_type":
                 mongo_query["variant_type"] = query.get("variant_type", "clinical")
                 LOG.debug("Set variant type to %s", mongo_query["variant_type"])
+                continue
 
             # Requests to filter based on gene panels, hgnc_symbols or
             # coordinate ranges must always be honored. They are always added to
@@ -214,12 +236,13 @@ class QueryHandler(object):
             # are used, addition of relative gene symbols is delayed until after
             # the rest of the query content is clear.
 
-            elif criterion in ["hgnc_symbols", "gene_panels"]:
+            if criterion in ["hgnc_symbols", "gene_panels"]:
                 gene_query = self.gene_filter(query, mongo_query)
                 if len(gene_query) > 0 or "hpo" in query.get("gene_panels", []):
                     mongo_query["hgnc_symbols"] = {"$in": gene_query}
+                continue
 
-            elif criterion == "chrom" and query.get("chrom"):  # filter by coordinates
+            if criterion == "chrom" and query.get("chrom"):  # filter by coordinates
                 coordinate_query = None
                 if category == "snv":
                     mongo_query["chromosome"] = query["chrom"]
@@ -227,10 +250,16 @@ class QueryHandler(object):
                         self.coordinate_filter(query, mongo_query)
                 else:  # sv
                     coordinate_query = [self.sv_coordinate_query(query)]
+                continue
 
-            elif criterion == "variant_ids" and variant_ids:
+            if criterion == "variant_ids" and variant_ids:
                 LOG.debug("Adding variant_ids %s to query" % ", ".join(variant_ids))
                 mongo_query["variant_id"] = {"$in": variant_ids}
+                continue
+
+            # Do not retrieve dismissed variants if hide_dismissed checkbox is checked in filter form
+            if criterion == "hide_dismissed" and query.get(criterion) is True:
+                mongo_query["dismiss_variant"] = {"$in": [None, []]}
 
             ##### end of fundamental query params
 
