@@ -803,12 +803,13 @@ class VariantHandler(VariantLoader):
 
         return file_name
 
-    def case_variants_count(self, case_id, institute_id):
+    def case_variants_count(self, case_id, institute_id, update_case=True):
         """Returns the sum of all variants for a case by type
 
         Args:
             case_id(str): _id of a case
             institute_id(str): id of an institute
+            update_case(bool): whether the case document should be updated with these stats
 
         Returns:
             variants_by_type(dict). A dictionary like this:
@@ -828,6 +829,11 @@ class VariantHandler(VariantLoader):
                 case_id, institute_id
             )
         )
+        # if case has stats and no update is needed, return variant count
+        case_obj = self.case(case_id=case_id)
+        if case_obj.get("variants_stats") and update_case is False:
+            return case_obj["variants_stats"]
+
         # Build query
         match = {"$match": {"case_id": case_id, "institute": institute_id}}
         group = {
@@ -849,6 +855,12 @@ class VariantHandler(VariantLoader):
                 variants_by_type[var_type][var_category] = item["total"]
             else:
                 variants_by_type[var_type] = {var_category: item["total"]}
+
+        # If case needs to be updated with variants stats
+        if case_obj.get("variants_stats") is None or update_case:
+            case_obj["variants_stats"] = variants_by_type
+            self.update_case(case_obj=case_obj, keep_date=True)
+
         return variants_by_type
 
     def sample_variants(self, variants, sample_name, category="snv"):
