@@ -8,21 +8,50 @@ from scout.server.extensions import store
 LOG = logging.getLogger(__name__)
 
 BYTES_IN_ONE_GIGABYTE = 1073741824  # (1024*1024*1024)
+DELETE_VARIANTS_HEADER = [
+    "Case n.",
+    "Ncases",
+    "Institute",
+    "Case name",
+    "Case ID",
+    "Case track",
+    "Analysis date",
+    "Status",
+    "Research",
+    "Total variants",
+    "Removed variants",
+]
+CASE_STATUS = ["solved", "archived", "migrated", "active", "inactive", "prioritized"]
+VARIANT_CATEGORIES = ["snv", "sv", "cancer", "cancer_sv", "str"]
 
 
 @click.command("variants", short_help="Delete variants for one or more cases")
 @click.option("-u", "--user", help="User running this command (email)", required=True)
 @click.option("-c", "--case-id", help="Case id")
 @click.option(
-    "-status",
-    type=click.Choice(["solved", "archived", "migrated", "active", "inactive", "prioritized"]),
+    "--status",
+    type=click.Choice(CASE_STATUS),
     multiple=True,
-    default=["solved", "archived", "migrated"],
+    default=[],
     help="Restrict to cases with specified status",
 )
-@click.option("-older-than", type=click.INT, default=0, help="Older than (months)")
-@click.option("-rank-threshold", type=click.INT, default=5, help="With rank threshold lower than")
-@click.option("-variants-threshold", type=click.INT, help="With more variants than")
+@click.option("--older-than", type=click.INT, default=0, help="Older than (months)")
+@click.option(
+    "--analysis-type",
+    type=click.Choice(["wgs", "wes", "panel"]),
+    multiple=True,
+    default=["wgs"],
+    help="Type of analysis",
+)
+@click.option("--rank-threshold", type=click.INT, default=5, help="With rank threshold lower than")
+@click.option("--variants-threshold", type=click.INT, help="With more variants than")
+@click.option(
+    "--keep-ctg",
+    type=click.Choice(VARIANT_CATEGORIES),
+    multiple=True,
+    required=False,
+    help="Do not delete one of more variant categories",
+)
 @click.option(
     "--dry-run",
     is_flag=True,
@@ -34,8 +63,10 @@ def variants(
     case_id: str,
     status: list,
     older_than: int,
+    analysis_type: list,
     rank_threshold: int,
     variants_threshold: int,
+    keep_ctg: list,
     dry_run: bool,
 ) -> None:
     """Delete variants for one or more cases"""
@@ -53,8 +84,7 @@ def variants(
     else:
         click.confirm("Variants are going to be deleted from database. Continue?", abort=True)
 
-    case_query = store.build_case_query(case_id, status, older_than)
-
+    case_query = store.build_case_query(case_id, status, older_than, analysis_type)
     # Estimate the average size of a variant document in database
     avg_var_size = store.collection_stats("variant").get("avgObjSize", 0)  # in bytes
 
@@ -64,13 +94,13 @@ def variants(
     filters = (
         f"Rank-score threshold:{rank_threshold}, case n. variants threshold:{variants_threshold}."
     )
+    click.echo("\t".join(DELETE_VARIANTS_HEADER))
     for nr, case in enumerate(cases, 1):
         case_id = case["_id"]
         case_n_variants = store.variant_collection.count_documents({"case_id": case_id})
         # Skip case if user provided a number of variants to keep and this number is less than total number of case variants
         if variants_threshold and case_n_variants < variants_threshold:
             continue
-        click.echo(f"#### Case n. {nr}/{n_cases} ###### {case['display_name']} ({case_id})")
         # Get evaluated variants for the case that haven't been dismissed
         case_evaluated = store.evaluated_variants(case_id=case_id)
         evaluated_not_dismissed = [
@@ -80,19 +110,53 @@ def variants(
         variants_to_keep = (
             case.get("suspects", []) + case.get("causatives", []) + evaluated_not_dismissed or []
         )
-        variants_query = store.delete_variants_query(case_id, variants_to_keep, rank_threshold)
+        variants_query = store.delete_variants_query(
+            case_id, variants_to_keep, rank_threshold, keep_ctg
+        )
 
         if dry_run:
             # Just print how many variants would be removed for this case
             remove_n_variants = store.variant_collection.count_documents(variants_query)
             total_deleted += remove_n_variants
-            click.echo(f"Remove {remove_n_variants} / {case_n_variants} total variants")
+            click.echo(
+                "\t".join(
+                    [
+                        str(nr),
+                        str(n_cases),
+                        case["owner"],
+                        case["display_name"],
+                        case_id,
+                        case.get("track", ""),
+                        str(case["analysis_date"]),
+                        case.get("status", ""),
+                        str(case.get("is_research", "")),
+                        str(case_n_variants),
+                        str(remove_n_variants),
+                    ]
+                )
+            )
             continue
 
         # delete variants specified by variants_query
         result = store.variant_collection.delete_many(variants_query)
-        click.echo(f"Deleted {result.deleted_count} / {case_n_variants} total variants")
         total_deleted += result.deleted_count
+        click.echo(
+            "\t".join(
+                [
+                    str(nr),
+                    str(n_cases),
+                    case["owner"],
+                    case["display_name"],
+                    case_id,
+                    case.get("track", ""),
+                    str(case["analysis_date"]),
+                    case.get("status", ""),
+                    str(case.get("is_research", "")),
+                    str(case_n_variants),
+                    str(result.deleted_count),
+                ]
+            )
+        )
 
         # Create event in database
         institute_obj = store.institute(case["owner"])
@@ -104,6 +168,9 @@ def variants(
                 institute=institute_obj, case=case, user=user_obj, link=url, content=filters
             )
 
+        # Update case variants count
+        store.case_variants_count(case_id, institute_obj["_id"], True)
+
     click.echo(f"Total {items_name}: {total_deleted}")
     click.echo(
         f"Estimated space freed (GB): {round((total_deleted * avg_var_size) / BYTES_IN_ONE_GIGABYTE, 4)}"
