@@ -106,6 +106,13 @@ def case(
         LOG.debug("Stack trace: {}".format(traceback.format_exc()))
         raise click.Abort()
 
+    if config_data.get("human_genome_build") not in [37, 38, "37", "38"]:
+        config_data["human_genome_build"] = int(
+            click.prompt(
+                f"Please enter a valid genome build for this case", type=click.Choice(["37", "38"])
+            )
+        )
+
     LOG.info("Use family %s" % config_data["family"])
 
     try:
