@@ -37,7 +37,6 @@ from .case_tags import (
     REV_PHENOTYPE_MAP,
     CASE_STATUSES,
     VERBS_MAP,
-    VERBS,
     SAMPLE_SOURCE,
     CASE_SEARCH_TERMS,
 )
@@ -64,6 +63,7 @@ COLLECTIONS = [
     "institute",
     "event",
     "case",
+    "case_group",
     "gene_panel",
     "hpo_term",
     "disease_term",
@@ -149,3 +149,30 @@ CALLERS = {
 
 BND_ALT_PATTERN = re.compile(r".*[\],\[](.*?):(.*?)[\],\[]")
 CHR_PATTERN = re.compile(r"(chr)?(.*)", re.IGNORECASE)
+
+AMINO_ACID_RESIDUE_3_TO_1 = {
+    "Ala": "A",
+    "Arg": "R",
+    "Asn": "N",
+    "Asp": "D",
+    "Asx": "B",
+    "Cys": "C",
+    "Glu": "E",
+    "Gln": "Q",
+    "Glx": "Z",
+    "Gly": "G",
+    "His": "H",
+    "Ile": "I",
+    "Leu": "L",
+    "Lys": "K",
+    "Met": "M",
+    "Phe": "F",
+    "Pro": "P",
+    "Ser": "S",
+    "Thr": "T",
+    "Trp": "W",
+    "Tyr": "Y",
+    "Val": "V",
+    "Ter": "*",
+    "del": "del",
+}
