@@ -43,6 +43,7 @@ individual = dict(
     msi=str,
     tumor_purity=float,
     tissue_type=str,
+    chromograph_images=str,  # path to image files
 )
 
 case = dict(
@@ -79,10 +80,9 @@ case = dict(
     phenotype_terms=list,  # List of dictionaries with phenotype information
     phenotype_groups=list,  # List of dictionaries with phenotype information
     madeline_info=str,  # madeline info is a full xml file
-    chromograph_image_files=str,  # path to dir
-    chromograph_prefixes=list,  # path to dir
     delivery_report=str,  # delivery report is a path to html file
-    cnv_report=str,  # CNV report is a path to html file
+    cnv_report=str,  # CNV report is a path to pdf file
+    coverage_qc_report=str,  # Covearge and qc report is a path to a html file
     vcf_files=dict,  # A dictionary with vcf files
     smn_tsv=str,  # path to an SMN TSV file
     diagnosis_phenotypes=list,  # List of references to diseases
@@ -91,4 +91,5 @@ case = dict(
     has_strvariants=bool,  # default=False
     is_migrated=bool,  # default=False
     multiqc=str,  # path to multiqc report
+    group=list,  # a list of group ids for cases conceptually grouped together with this
 )
