@@ -62,6 +62,7 @@ def parse_case_data(
     delivery_report=None,
     multiqc=None,
     cnv_report=None,
+    coverage_qc_report=None,
 ):
     """Parse all data necessary for loading a case into scout
 
@@ -82,6 +83,7 @@ def parse_case_data(
         peddy_ped(str): Path to a peddy ped
         multiqc(str): Path to dir with multiqc information
         cnv_report: Path to pdf file with CNV report
+        coverage_qc_report: Path to html file with coverage and qc report
 
     Returns:
         config_data(dict): Holds all the necessary information for loading
@@ -143,6 +145,9 @@ def parse_case_data(
     )
 
     config_data["cnv_report"] = cnv_report if cnv_report else config_data.get("cnv_report")
+    config_data["coverage_qc_report"] = (
+        coverage_qc_report if coverage_qc_report else config_data.get("coverage_qc_report")
+    )
 
     config_data["rank_model_version"] = str(config_data.get("rank_model_version", ""))
     config_data["rank_score_threshold"] = config_data.get("rank_score_threshold", 0)
@@ -325,6 +330,7 @@ def parse_individual(sample):
             'msi': str,
             'tumor_purity': float,
             'tissue_type': str,
+            'chromograph_images': str
         }
 
     """
@@ -418,6 +424,8 @@ def parse_individual(sample):
 
     ind_info["tissue_type"] = sample.get("tissue_type")
 
+    ind_info["chromograph_images"] = sample.get("chromograph_images")
+
     # Remove key-value pairs from ind_info where key==None and return
     return removeNoneValues(ind_info)
 
@@ -516,10 +524,9 @@ def parse_case(config):
         "peddy_check": config.get("peddy_check"),
         "delivery_report": config.get("delivery_report"),
         "cnv_report": config.get("cnv_report"),
+        "coverage_qc_report": config.get("coverage_qc_report"),
         "multiqc": config.get("multiqc"),
         "track": config.get("track", "rare"),
-        "chromograph_image_files": config.get("chromograph_image_files"),
-        "chromograph_prefixes": config.get("chromograph_prefixes"),
     }
 
     # add SMN info
@@ -582,15 +589,14 @@ def parse_ped(ped_stream, family_type="ped"):
     return family_id, samples
 
 
-def removeNoneValues(dict):
+def removeNoneValues(dictionary):
     """If value = None in key/value pair, the pair is removed.
         Python >3
     Args:
-        dict: dictionary
+        dictionary: dict
 
     Returns:
-        dictionary
-
+        dict
     """
 
-    return {k: v for k, v in dict.items() if v is not None}
+    return {k: v for k, v in dictionary.items() if v is not None}
