@@ -7,6 +7,7 @@ import os
 
 import query_phenomizer
 import requests
+from bson.objectid import ObjectId
 from bs4 import BeautifulSoup
 from flask import current_app, url_for, flash
 from flask_login import current_user
@@ -30,6 +31,7 @@ from scout.constants.variant_tags import (
     MANUAL_RANK_OPTIONS,
 )
 from scout.export.variant import export_mt_variants
+from scout.server.extensions import store
 from scout.parse.matchmaker import (
     genomic_features,
     hpo_terms,
@@ -39,10 +41,12 @@ from scout.parse.matchmaker import (
 from scout.server.blueprints.variant.controllers import variant as variant_decorator
 from scout.server.utils import institute_and_case
 from scout.utils.matchmaker import matchmaker_request
+from scout.utils.scout_requests import post_request_json
 
 LOG = logging.getLogger(__name__)
 
 STATUS_MAP = {"solved": "bg-success", "archived": "bg-warning"}
+JSON_HEADERS = {"Content-type": "application/json; charset=utf-8", "Accept": "text/json"}
 
 
 def case(store, institute_obj, case_obj):
@@ -77,6 +81,14 @@ def case(store, institute_obj, case_obj):
 
     case_obj["assignees"] = [store.user(user_email) for user_email in case_obj.get("assignees", [])]
 
+    # Fetch ids for grouped cases
+    case_groups = {}
+    case_group_label = {}
+    if case_obj.get("group"):
+        for group in case_obj.get("group"):
+            case_groups[group] = list(store.cases(group=group))
+            case_group_label[group] = store.case_group_label(group)
+
     # Fetch the variant objects for suspects and causatives
     suspects = [
         store.variant(variant_id) or variant_id for variant_id in case_obj.get("suspects", [])
@@ -177,7 +189,7 @@ def case(store, institute_obj, case_obj):
 
     events = list(store.events(institute_obj, case=case_obj))
     for event in events:
-        event["verb"] = VERBS_MAP[event["verb"]]
+        event["verb"] = VERBS_MAP.get(event["verb"], "did %s for".format(event["verb"]))
 
     case_obj["clinvar_variants"] = store.case_to_clinVars(case_obj["_id"])
 
@@ -197,6 +209,8 @@ def case(store, institute_obj, case_obj):
         "managed_variants": [var for var in store.check_managed(case_obj=case_obj)],
         "comments": store.events(institute_obj, case=case_obj, comments=True),
         "hpo_groups": pheno_groups,
+        "case_groups": case_groups,
+        "case_group_label": case_group_label,
         "events": events,
         "suspects": suspects,
         "causatives": causatives,
@@ -268,10 +282,16 @@ def case_report_content(store, institute_obj, case_obj):
         except ValueError as err:
             sex = 0
         individual["sex_human"] = SEX_MAP[sex]
-        individual["phenotype_human"] = PHENOTYPE_MAP.get(individual["phenotype"])
+
+        pheno_map = PHENOTYPE_MAP
+        if case_obj.get("track", "rare") == "cancer":
+            pheno_map = CANCER_PHENOTYPE_MAP
+
+        individual["phenotype_human"] = pheno_map.get(individual["phenotype"])
 
     dismiss_options = DISMISS_VARIANT_OPTIONS
-    if case_obj.get("track") == "cancer":
+    data["cancer"] = case_obj.get("track") == "cancer"
+    if data["cancer"]:
         dismiss_options = {
             **DISMISS_VARIANT_OPTIONS,
             **CANCER_SPECIFIC_VARIANT_DISMISS_OPTIONS,
@@ -724,6 +744,65 @@ def update_clinical_filter_hpo(store, current_user, institute_id, case_name, hpo
     store.update_clinical_filter_hpo(institute_obj, case_obj, user_obj, link, hpo_clinical_filter)
 
 
+def add_case_group(store, current_user, institute_id, case_name, group=None):
+    """Bind a case group in a selected a case, creating it in current institute if not given.
+
+    Args:
+        current_user    (user)current user
+        institute_id    (str)institute id
+        case_name       (str)case display name
+        group           (str)case group id - converts to ObjectId
+    Returns:
+        updated_case    (InsertOneResult)
+    """
+
+    institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
+    link = url_for("cases.case", institute_id=institute_id, case_name=case_name)
+    user_obj = store.user(current_user.email)
+
+    if not group:
+        group = store.init_case_group(institute_id)
+
+    current_group_ids = set(case_obj.get("group", []))
+    current_group_ids.add(ObjectId(group))
+
+    updated_case = store.update_case_group_ids(
+        institute_obj, case_obj, user_obj, link, list(current_group_ids)
+    )
+    return updated_case
+
+
+def remove_case_group(store, current_user, institute_id, case_name, case_group):
+    """Remove a case group from selected institute - and from db if it is no longer in use."""
+
+    institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
+    link = url_for("cases.case", institute_id=institute_id, case_name=case_name)
+    user_obj = store.user(current_user.email)
+
+    current_group_ids = case_obj.get("group", [])
+
+    # STR OBJID mismatch?
+    current_group_ids.remove(ObjectId(case_group))
+    updated_case = store.update_case_group_ids(
+        institute_obj, case_obj, user_obj, link, current_group_ids
+    )
+
+    current_group_cases = store.case_ids_from_group_id(case_group)
+
+    if current_group_cases == []:
+        store.remove_case_group(case_group)
+
+    return updated_case
+
+
+def case_group_update_label(store, case_group_id, case_group_label):
+    """Update a case group label."""
+
+    result = store.case_group_update_label(ObjectId(case_group_id), case_group_label)
+
+    return result
+
+
 def vcf2cytosure(store, institute_id, case_name, individual_id):
     """vcf2cytosure CGH file for inidividual."""
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
@@ -741,6 +820,131 @@ def multiqc(store, institute_id, case_name):
     return dict(institute=institute_obj, case=case_obj)
 
 
+def prepare_beacon_req_params():
+    """Prepares URL and Headers for sending a request to the beacon server.
+
+    Returns:
+        url, headers(tuple)
+    """
+    req_url = current_app.config.get("BEACON_URL")
+    beacon_token = current_app.config.get("BEACON_TOKEN")
+    if not req_url or not beacon_token:
+        return
+    req_headers = JSON_HEADERS
+    req_headers["X-Auth-Token"] = beacon_token
+    return req_url, req_headers
+
+
+def beacon_remove(case_id):
+    """Remove all variants from a case in Beacon by handling a POST request to the /apiv1.0/delete Beacon endpoint.
+
+    Args:
+        case_id(str): A case _id
+
+    """
+    if prepare_beacon_req_params() is None:
+        flash(
+            "Please check config file. It should contain both BEACON_URL and BEACON_TOKEN",
+            "warning",
+        )
+        return
+    request_url, req_headers = prepare_beacon_req_params()
+
+    case_obj = store.case(case_id=case_id)
+    beacon_submission = case_obj.get("beacon")
+
+    if beacon_submission is None:
+        flash("Couldn't find a valid beacon submission for this case", "warning")
+        return
+
+    # Prepare beacon request data
+    assembly = "GRCh37" if "37" in str(case_obj["genome_build"]) else "GRCh38"
+    dataset_id = "_".join([case_obj["owner"], assembly])
+    samples = [sample for sample in beacon_submission.get("samples", [])]
+    data = {"dataset_id": dataset_id, "samples": samples}
+    resp = post_request_json("/".join([request_url, "delete"]), data, req_headers)
+    flash_color = "success"
+    if resp.get("status_code") == 200:
+        store.case_collection.update({"_id": case_obj["_id"]}, {"$unset": {"beacon": 1}})
+    else:
+        flash_color = "warning"
+    flash(f"Beacon responded:{resp['message']}", flash_color)
+
+
+def beacon_add(form):
+    """Save variants from one or more case samples to the Beacon server.
+       Handle a POST request to the /apiv1.0/add Beacon endpoint
+
+    Args:
+        form(werkzeug.datastructures.ImmutableMultiDict): beacon submission form
+
+    """
+    if prepare_beacon_req_params() is None:
+        flash(
+            "Please check config file. It should contain both BEACON_URL and BEACON_TOKEN",
+            "warning",
+        )
+        return
+    request_url, req_headers = prepare_beacon_req_params()
+
+    case_obj = store.case(case_id=form.get("case"))
+    # define case individuals (individual_id, same as in VCF) to filter VCF files with
+    individuals = []
+    if form.get("samples") == "affected":
+        individuals = [
+            ind["individual_id"] for ind in case_obj["individuals"] if ind["phenotype"] == 2
+        ]
+    else:
+        individuals = [ind["individual_id"] for ind in case_obj["individuals"]]
+
+    # define genes to filter VCF files with
+    gene_filter = set()
+    for panel in form.getlist("panels"):
+        gene_filter.update(store.panel_to_genes(panel_id=panel, gene_format="hgnc_id"))
+    gene_filter = list(gene_filter)
+
+    submission = {
+        "created_at": datetime.datetime.now(),
+        "user": current_user.email,
+        "samples": individuals,
+        "panels": form.getlist("panels"),
+        "vcf_files": [],
+    }
+
+    # Prepare beacon request data
+    assembly = "GRCh37" if "37" in str(case_obj["genome_build"]) else "GRCh38"
+    data = {
+        "dataset_id": "_".join([case_obj["owner"], assembly]),
+        "samples": individuals,
+        "assemblyId": assembly,
+    }
+    if gene_filter:  # Gene filter is not mandatory
+        data["genes"] = {"ids": gene_filter, "id_type": "HGNC"}
+
+    # loop over selected VCF files and send an add request to Beacon for each one of them
+    vcf_files = form.getlist("vcf_files")
+    if not vcf_files:
+        flash("Please select at least one VCF file to save to Beacon", "warning")
+        return
+    for vcf_key in form.getlist("vcf_files"):
+        data["vcf_path"] = case_obj["vcf_files"].get(vcf_key)
+        resp = post_request_json("/".join([request_url, "add"]), data, req_headers)
+        if resp.get("status_code") != 200:
+            flash(f"Beacon responded:{resp['message']}", "warning")
+            continue
+        submission["vcf_files"].append(vcf_key)
+
+    if len(submission["vcf_files"]) > 0:
+        flash(
+            f"Variants from the following files are going to be saved to Beacon:{submission['vcf_files']}",
+            "success",
+        )
+        store.case_collection.find_one_and_update(
+            {"_id": case_obj["_id"]}, {"$set": {"beacon": submission}}
+        )
+    return
+
+
 def mme_add(
     store,
     user_obj,
