@@ -30,7 +30,7 @@ from flask_weasyprint import HTML, render_pdf
 from werkzeug.datastructures import Headers
 
 from scout.constants import SAMPLE_SOURCE
-from scout.server.extensions import mail, store
+from scout.server.extensions import mail, store, gens
 from scout.server.utils import institute_and_case, templated, user_institutes
 
 from . import controllers
@@ -74,6 +74,7 @@ def case(institute_id, case_name):
         case=case_obj,
         mme_nodes=current_app.mme_nodes,
         tissue_types=SAMPLE_SOURCE,
+        gens_info=gens.connection_settings(case_obj.get("genome_build")),
         **data,
     )
 
@@ -87,6 +88,22 @@ def sma(institute_id, case_name):
     return dict(institute=institute_obj, case=case_obj, format="html", **data)
 
 
+@cases_bp.route("/beacon_submit", methods=["POST"])
+def beacon_submit():
+    """Submit case variants to Beacon"""
+
+    controllers.beacon_add(request.form)
+    return redirect(request.referrer)
+
+
+@cases_bp.route("/beacon_remove/<case_id>", methods=["GET"])
+def beacon_remove(case_id):
+    """Remove all variants from a case from Beacon"""
+
+    controllers.beacon_remove(case_id)
+    return redirect(request.referrer)
+
+
 @cases_bp.route("/<institute_id>/<case_name>/mme_matches", methods=["GET", "POST"])
 @templated("cases/matchmaker.html")
 def matchmaker_matches(institute_id, case_name):
@@ -94,7 +111,7 @@ def matchmaker_matches(institute_id, case_name):
     # check that only authorized users can access MME patients matches
     panel = 1
     if request.method == "POST":
-        panel = panel = request.form.get("pane_id")
+        panel = request.form.get("pane_id")
     user_obj = store.user(current_user.email)
     if "mme_submitter" not in user_obj["roles"]:
         flash("unauthorized request", "warning")
@@ -445,10 +462,11 @@ def mt_report(institute_id, case_name):
 def case_diagnosis(institute_id, case_name):
     """Add or remove a diagnosis for a case."""
 
+    level = "phenotype" if "phenotype" in request.form else "gene"
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
     user_obj = store.user(current_user.email)
     link = url_for(".case", institute_id=institute_id, case_name=case_name)
-    level = "phenotype" if "phenotype" in request.form else "gene"
+
     omim_id = request.form["omim_term"].split("|")[0]
 
     if not "OMIM:" in omim_id:  # Could be an omim number provided by user
@@ -456,7 +474,7 @@ def case_diagnosis(institute_id, case_name):
 
     # Make sure omim term exists in database:
     omim_obj = store.disease_term(omim_id.strip())
-    if not omim_obj:
+    if level == "phenotype" and omim_obj is None:
         flash("Couldn't find any disease term with id: {}".format(omim_id), "warning")
         return redirect(request.referrer)
 
@@ -678,6 +696,23 @@ def assign(institute_id, case_name, user_id=None, inactivate=False):
     return redirect(request.referrer)
 
 
+@cases_bp.route("/api/v1/<institute_id>/cases")
+def caselist(institute_id):
+    """Search for cases for autocompletion"""
+    query = request.args.get("query")
+    if query is None:
+        return abort(500)
+    display_names = sorted(
+        [
+            case["display_name"]
+            for case in store.cases(owner=institute_id, name_query="case:" + query)
+        ]
+    )
+    json_terms = [{"name": "{}".format(display_name)} for display_name in display_names]
+
+    return jsonify(json_terms)
+
+
 @cases_bp.route("/api/v1/hpo-terms")
 def hpoterms():
     """Search for HPO terms."""
@@ -838,6 +873,41 @@ def cnv_report(institute_id, case_name):
     return send_from_directory(out_dir, filename)
 
 
+@cases_bp.route("/<institute_id>/<case_name>/coverage-qc-report")
+def coverage_qc_report(institute_id, case_name):
+    """Display coverage and qc report."""
+    _, case_obj = institute_and_case(store, institute_id, case_name)
+    data = controllers.multiqc(store, institute_id, case_name)
+    if data["case"].get("coverage_qc_report") is None:
+        return abort(404)
+
+    coverage_qc_report = data["case"]["coverage_qc_report"]
+    report_format = request.args.get("format", "html")
+    if report_format == "pdf":
+        try:  # file could not be available
+            html_file = open(coverage_qc_report, "r")
+            source_code = html_file.read()
+            return render_pdf(
+                HTML(string=source_code),
+                download_filename=case_obj["display_name"]
+                + "_"
+                + datetime.datetime.now().strftime("%Y-%m-%d")
+                + "_coverage_qc_report.pdf",
+            )
+        except Exception as ex:
+            flash(
+                "An error occurred while downloading delivery report {} -- {}".format(
+                    coverage_qc_report, ex
+                ),
+                "warning",
+            )
+
+    out_dir = os.path.dirname(coverage_qc_report)
+    filename = os.path.basename(coverage_qc_report)
+
+    return send_from_directory(out_dir, filename)
+
+
 @cases_bp.route("/<institute_id>/<case_name>/share", methods=["POST"])
 def share(institute_id, case_name):
     """Share a case with a different institute."""
@@ -910,6 +980,40 @@ def update_clinical_filter_hpo(institute_id, case_name):
     return redirect(request.referrer)
 
 
+@cases_bp.route("/<institute_id>/<case_name>/add_case_group", methods=["GET", "POST"])
+def add_case_group(institute_id, case_name):
+    """Add a new case group for an institute and bind it in selected case.
+
+    GET request (with no group_id) requests init of a new group
+    POST request adds other_case_name to the group
+    """
+    group_id = request.form.get("group_id", None)
+    if request.method == "POST":
+        case_name = request.form.get("other_case_name")
+
+    controllers.add_case_group(store, current_user, institute_id, case_name, group_id)
+
+    return redirect(request.referrer)
+
+
+@cases_bp.route("/<institute_id>/<case_name>/<case_group>/remove_case_group", methods=["GET"])
+def remove_case_group(institute_id, case_name, case_group):
+    """Unbind a case group from a case. Remove the group if it is no longer in use."""
+    controllers.remove_case_group(store, current_user, institute_id, case_name, case_group)
+
+    return redirect(request.referrer)
+
+
+@cases_bp.route("/<case_group>/case_group_update_label", methods=["POST"])
+def case_group_update_label(case_group):
+    """Unbind a case group from a case. Remove the group if it is no longer in use."""
+    label = request.form.get("label", "unlabeled")
+
+    controllers.case_group_update_label(store, case_group, label)
+
+    return redirect(request.referrer)
+
+
 @cases_bp.route("/<institute_id>/<case_name>/download-hpo-genes", methods=["GET"])
 def download_hpo_genes(institute_id, case_name):
     """Download the genes contained in a case dynamic gene list"""
@@ -959,29 +1063,71 @@ def multiqc(institute_id, case_name):
     return send_from_directory(out_dir, filename)
 
 
-@cases_bp.route("/<institute_id>/<case_name>/roh_images/<image>")
-def host_roh_image(institute_id, case_name, image):
-    """Generate ROH image file paths"""
-    return host_image_aux(institute_id, case_name, image, "roh_images")
+@cases_bp.route(
+    "/<institute_id>/<case_name>/<individual>/upd_regions_images/<image>", methods=["GET", "POST"]
+)
+def host_upd_regions_image(institute_id, case_name, individual, image):
+    """Generate UPD REGIONS image file paths"""
+    LOG.debug("REGIONS")
+    return host_image_aux(institute_id, case_name, individual, image, "upd_regions")
 
 
-@cases_bp.route("/<institute_id>/<case_name>/upd_images/<image>")
-def host_upd_image(institute_id, case_name, image):
+@cases_bp.route(
+    "/<institute_id>/<case_name>/<individual>/upd_sites_images/<image>", methods=["GET", "POST"]
+)
+def host_upd_sites_image(institute_id, case_name, individual, image):
     """Generate UPD image file paths"""
-    return host_image_aux(institute_id, case_name, image, "upd_images")
+    return host_image_aux(institute_id, case_name, individual, image, "upd_sites")
 
 
-@cases_bp.route("/<institute_id>/<case_name>/chr_images/<image>")
-def host_chr_image(institute_id, case_name, image):
-    """Generate CHR image file paths"""
-    return host_image_aux(institute_id, case_name, image, "chr_images")
+@cases_bp.route(
+    "/<institute_id>/<case_name>/<individual>/coverage_images/<image>", methods=["GET", "POST"]
+)
+def host_coverage_image(institute_id, case_name, individual, image):
+    """Generate Coverage image file paths"""
+    return host_image_aux(institute_id, case_name, individual, image, "coverage")
 
 
-def host_image_aux(institute_id, case_name, image, imgstr):
+@cases_bp.route(
+    "/<institute_id>/<case_name>/<individual>/autozygous_images/<image>", methods=["GET", "POST"]
+)
+def host_autozygous_image(institute_id, case_name, individual, image):
+    """Generate Coverage image file paths"""
+    return host_image_aux(institute_id, case_name, individual, image, "autozygous")
+
+
+@cases_bp.route(
+    "/<institute_id>/<case_name>/<individual>/ideograms/<image>", methods=["GET", "POST"]
+)
+def host_chr_image(institute_id, case_name, individual, image):
+    """Generate CHR image file paths. Points to servers 'public/static'"""
+    public_folder = "/public/static/ideograms/"
+    img_path = public_folder + image
+    LOG.debug("ideaogram: {}".format(img_path))
+    return send_from_directory(img_path, image)
+
+
+def host_image_aux(institute_id, case_name, individual, image, key):
     """Auxilary function for generate absolute file paths"""
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
-    chr_path = case_obj.get("chromograph_image_files")
-    abs_path = os.path.abspath(chr_path)
-    img_path = abs_path + "/" + imgstr
-    LOG.debug("Attempting to send {}/{}".format(img_path, image))
-    return send_from_directory(img_path, image)
+    # Find path
+    for ind in case_obj["individuals"]:
+        if ind["individual_id"] == individual:
+            # LOG.debug("ind host_image_aux: {}".format(ind))
+            try:
+                # path contains both dir structure and a file prefix
+                path = ind["chromograph_images"][key]
+                abs_path = os.path.abspath(path)
+                img_path = abs_path + image.split("-")[-1]  # get suffix
+                return send_file(img_path)
+            except Exception as err:
+                # redirect to missing file icon upon error
+                LOG.warning("send_file() exception: {}".format(err))
+                return redirect("/public/static/file-earmark-x.svg")
+
+
+def _generate_csv(header, lines):
+    """Download a text file composed of any header and lines"""
+    yield header + "\n"
+    for line in lines:  # lines have already quoted fields
+        yield line + "\n"
