@@ -20,9 +20,14 @@ from scout.constants import (
 )
 from scout.parse.variant.ids import parse_document_id
 from scout.server.links import ensembl, get_variant_links
-from scout.server.utils import institute_and_case, user_institutes, variant_case
+from scout.server.utils import (
+    case_append_alignments,
+    institute_and_case,
+    user_institutes,
+    variant_case,
+)
 from scout.utils.scout_requests import fetch_refseq_version
-
+from scout.server.extensions import cloud_tracks, gens
 
 from .utils import (
     add_gene_info,
@@ -40,6 +45,26 @@ from .utils import (
 LOG = logging.getLogger(__name__)
 
 
+def get_igv_tracks(build="37"):
+    """Return all available IGV tracks for the given genome build, as a set
+
+    Args:
+        build(str): "37" or "38"
+
+    Returns:
+        igv_tracks(set): A set of track names for a given genome build
+    """
+    igv_tracks = set()
+    # Collect hardcoded tracks, common for all Scout instances
+    for track in IGV_TRACKS.get(build, []):
+        igv_tracks.add(track.get("name"))
+    # Collect instance-specif cloud public tracks, if available
+    if hasattr(cloud_tracks, "public_tracks"):
+        for track in cloud_tracks.public_tracks.get(build, []):
+            igv_tracks.add(track.get("name"))
+    return igv_tracks
+
+
 def variant(
     store,
     institute_id,
@@ -85,6 +110,7 @@ def variant(
             'dismiss_variant_options': DISMISS_VARIANT_OPTIONS,
             'ACMG_OPTIONS': ACMG_OPTIONS,
             'igv_tracks': IGV_TRACKS,
+            'gens_info': <dict>,
             'evaluations': <list(evaluations)>,
         }
 
@@ -111,16 +137,26 @@ def variant(
     if genome_build not in ["37", "38"]:
         genome_build = "37"
 
+    # add default panels extra gene information
     panels = default_panels(store, case_obj)
     variant_obj = add_gene_info(store, variant_obj, gene_panels=panels, genome_build=genome_build)
+
     # Add information about bam files and create a region vcf
     if add_case:
         variant_case(store, case_obj, variant_obj)
 
+    # Fetch ids for grouped cases and prepare alignment display
+    case_groups = {}
+    if case_obj.get("group"):
+        for group in case_obj.get("group"):
+            case_groups[group] = list(store.cases(group=group))
+            for grouped_case in case_groups[group]:
+                case_append_alignments(grouped_case)
+
     # Collect all the events for the variant
     events = list(store.events(institute_obj, case=case_obj, variant_id=variant_id))
     for event in events:
-        event["verb"] = VERBS_MAP[event["verb"]]
+        event["verb"] = VERBS_MAP.get(event["verb"], "did %s for".format(event["verb"]))
 
     # Comments are not on case level so these needs to be fetched on their own
     variant_obj["comments"] = store.events(
@@ -211,6 +247,7 @@ def variant(
     return {
         "institute": institute_obj,
         "case": case_obj,
+        "case_groups": case_groups,
         "variant": variant_obj,
         variant_category: True,
         "causatives": other_causatives,
@@ -222,7 +259,8 @@ def variant(
         "dismiss_variant_options": dismiss_options,
         "mosaic_variant_options": MOSAICISM_OPTIONS,
         "ACMG_OPTIONS": ACMG_OPTIONS,
-        "igv_tracks": IGV_TRACKS[genome_build],
+        "igv_tracks": get_igv_tracks(genome_build),
+        "gens_info": gens.connection_settings(genome_build),
         "evaluations": evaluations,
     }
 
