@@ -83,7 +83,6 @@ def update_transcripts_information(variant_gene, hgnc_gene, variant_obj, genome_
     # Add the transcripts to the gene object
     hgnc_gene["transcripts_dict"] = transcripts_dict
     hgnc_symbol = hgnc_gene["hgnc_symbol"]
-    refseq_transcripts = []
 
     # First loop over the variants transcripts
     for transcript in variant_gene.get("transcripts", []):
@@ -98,7 +97,7 @@ def update_transcripts_information(variant_gene, hgnc_gene, variant_obj, genome_
             transcript["is_primary"] = True
 
         # Add the transcript links
-        add_tx_links(transcript, genome_build)
+        add_tx_links(transcript, genome_build, hgnc_symbol)
         # If the transcript has a ref seq identifier we add that
         # to the variants transcript
         refseq_id = hgnc_transcript.get("refseq_id")
@@ -107,7 +106,6 @@ def update_transcripts_information(variant_gene, hgnc_gene, variant_obj, genome_
         transcript["refseq_id"] = refseq_id
         variant_obj["has_refseq"] = True
 
-        refseq_transcripts.append(transcript)
         # Check if the refseq id are disease associated
         if refseq_id in disease_associated_no_version:
             transcript["is_disease_associated"] = True
@@ -115,19 +113,17 @@ def update_transcripts_information(variant_gene, hgnc_gene, variant_obj, genome_
         # Since a ensemble transcript can have multiple refseq identifiers we add all of
         # those
         transcript["refseq_identifiers"] = hgnc_transcript.get("refseq_identifiers", [])
-
         transcript["change_str"] = transcript_str(transcript, hgnc_symbol)
 
-    variant_gene["primary_transcripts"] = refseq_transcripts
-
 
 def add_gene_info(store, variant_obj, gene_panels=None, genome_build=None):
-    """Adds information to variant genes from hgnc genes and gene panels.
+    """Adds information to variant genes from hgnc genes and selected gene panels.
 
     Variants are annotated with gene and transcript information from VEP. In Scout the database
     keeps updated and extended information about genes and transcript. This function will compliment
      the VEP information with the updated database information.
     Also there is sometimes additional information that are manually curated in the gene panels.
+    Only the selected panels passed to this function (typically default) are used.
     This information needs to be added to the variant before sending it to the template.
 
     This function will loop over all genes and add that extra information.
