@@ -5,7 +5,7 @@ import urllib.parse
 from datetime import date
 from pprint import pprint as pp
 
-from flask import Response, flash, request, url_for, session
+from flask import Response, flash, request, url_for
 from flask_login import current_user
 from flask_mail import Message
 from werkzeug.datastructures import Headers, MultiDict
@@ -19,6 +19,7 @@ from scout.constants import (
     CANCER_TIER_OPTIONS,
     CLINSIG_MAP,
     DISMISS_VARIANT_OPTIONS,
+    CANCER_SPECIFIC_VARIANT_DISMISS_OPTIONS,
     MANUAL_RANK_OPTIONS,
     MOSAICISM_OPTIONS,
     SEVERE_SO_TERMS,
@@ -29,8 +30,8 @@ from scout.constants.acmg import ACMG_CRITERIA
 from scout.constants.variants_export import EXPORT_HEADER, VERIFIED_VARIANTS_HEADER
 from scout.export.variant import export_verified_variants
 from scout.server.blueprints.genes.controllers import gene
-from scout.server.blueprints.variant.utils import predictions
-from scout.server.links import add_gene_links, add_tx_links, ensembl, cosmic_link
+from scout.server.blueprints.variant.utils import predictions, clinsig_human
+from scout.server.links import str_source_link, ensembl, cosmic_link
 from scout.server.utils import (
     case_append_alignments,
     institute_and_case,
@@ -84,6 +85,10 @@ def variants(store, institute_obj, case_obj, variants_query, variant_count, page
             )
 
         variant_obj["clinical_assessments"] = get_manual_assessments(clinical_var_obj)
+
+        if case_obj.get("group"):
+            variant_obj["group_assessments"] = _get_group_assessments(store, case_obj, variant_obj)
+
         variants.append(
             parse_variant(
                 store, institute_obj, case_obj, variant_obj, update=True, genome_build=genome_build
@@ -93,6 +98,35 @@ def variants(store, institute_obj, case_obj, variants_query, variant_count, page
     return {"variants": variants, "more_variants": more_variants}
 
 
+def _get_group_assessments(store, case_obj, variant_obj):
+    """Return manual variant assessments for other cases grouped with this one.
+
+    Args:
+        case_obj
+    Returns:
+        group_assessments(list(dict))
+    """
+    group_assessments = []
+
+    group_case_ids = set()
+    for group_id in case_obj.get("group"):
+        group_case_ids.update(store.case_ids_from_group_id(group_id))
+
+        for group_case_id in group_case_ids:
+            # Returning an extra assessment for variants from the same case is pointless
+            if group_case_id == case_obj["_id"]:
+                continue
+
+            cohort_var_obj = store.variant(
+                case_id=group_case_id,
+                simple_id=variant_obj["simple_id"],
+                variant_type=variant_obj["variant_type"],
+            )
+            group_assessments.extend(get_manual_assessments(cohort_var_obj))
+
+    return group_assessments
+
+
 def sv_variants(store, institute_obj, case_obj, variants_query, variant_count, page=1, per_page=50):
     """Pre-process list of SV variants."""
     skip_count = per_page * max(page - 1, 0)
@@ -120,6 +154,40 @@ def sv_variants(store, institute_obj, case_obj, variants_query, variant_count, p
     return {"variants": variants, "more_variants": more_variants}
 
 
+def str_variants(
+    store, institute_obj, case_obj, variants_query, variant_count, page=1, per_page=50
+):
+    """Pre-process list of STR variants."""
+
+    return_view_data = {}
+
+    # case bam_files for quick access to alignment view.
+    case_append_alignments(case_obj)
+
+    # Fetch ids for grouped cases and prepare alignment display
+    case_groups = {}
+    if case_obj.get("group"):
+        for group in case_obj.get("group"):
+            case_groups[group] = list(store.cases(group=group))
+            for grouped_case in case_groups[group]:
+                case_append_alignments(grouped_case)
+        return_view_data["case_groups"] = case_groups
+
+    return_view_data.update(
+        variants(
+            store,
+            institute_obj,
+            case_obj,
+            variants_query,
+            variant_count,
+            page=page,
+            per_page=per_page,
+        )
+    )
+
+    return return_view_data
+
+
 def get_manual_assessments(variant_obj):
     """Return manual assessments ready for display.
 
@@ -176,14 +244,18 @@ def get_manual_assessments(variant_obj):
                 assessment["display_class"] = classification["color"]
 
             if assessment_type == "dismiss_variant":
+                dismiss_variant_options = {
+                    **DISMISS_VARIANT_OPTIONS,
+                    **CANCER_SPECIFIC_VARIANT_DISMISS_OPTIONS,
+                }
                 assessment["label"] = "Dismissed"
                 assessment["title"] = "dismiss:<br>"
                 for reason in variant_obj[assessment_type]:
                     if not isinstance(reason, int):
                         reason = int(reason)
                         assessment["title"] += "<strong>{}</strong> - {}<br><br>".format(
-                            DISMISS_VARIANT_OPTIONS[reason]["label"],
-                            DISMISS_VARIANT_OPTIONS[reason]["description"],
+                            dismiss_variant_options[reason]["label"],
+                            dismiss_variant_options[reason]["description"],
                         )
                 assessment["display_class"] = "secondary"
 
@@ -203,18 +275,6 @@ def get_manual_assessments(variant_obj):
     return assessments
 
 
-def str_variants(
-    store, institute_obj, case_obj, variants_query, variant_count, page=1, per_page=50
-):
-    """Pre-process list of STR variants."""
-
-    # Nothing unique to STRs on this level. Inheritance? yep, you will want it.
-
-    # case bam_files for quick access to alignment view.
-    case_append_alignments(case_obj)
-    return variants(store, institute_obj, case_obj, variants_query, variant_count, page, per_page)
-
-
 def parse_variant(
     store, institute_obj, case_obj, variant_obj, update=False, genome_build="37", get_compounds=True
 ):
@@ -288,7 +348,13 @@ def parse_variant(
     variant_obj["length"] = {100000000000: "inf", -1: "n.d."}.get(variant_length, variant_length)
     if not "end_chrom" in variant_obj:
         variant_obj["end_chrom"] = variant_obj["chromosome"]
+
+    # variant level links shown on variants page
     variant_obj["cosmic_link"] = cosmic_link(variant_obj)
+    variant_obj["str_source_link"] = str_source_link(variant_obj)
+    # Format clinvar information
+    variant_obj["clinsig_human"] = clinsig_human(variant_obj) if variant_obj.get("clnsig") else None
+
     return variant_obj
 
 
@@ -390,7 +456,9 @@ def variant_export_genes_info(store, gene_list):
     """
     gene_ids = []
     gene_names = []
+    canonical_txs = []
     hgvs_c = []
+    pt_c = []
 
     gene_info = []
 
@@ -401,20 +469,23 @@ def variant_export_genes_info(store, gene_list):
         gene_ids.append(hgnc_id)
         gene_names.append(gene_name)
 
+        if gene_obj.get("canonical_transcript"):
+            canonical_txs.append(gene_obj.get("canonical_transcript"))
+
         hgvs_nucleotide = "-"
+        protein_change = "-"
         # gather HGVS info from gene transcripts
+
         transcripts_list = gene_obj.get("transcripts")
         for transcript_obj in transcripts_list:
-            if (
-                transcript_obj.get("is_canonical") is not None
-                and transcript_obj.get("is_canonical") is True
-            ):
-                hgvs_nucleotide = str(transcript_obj.get("coding_sequence_name"))
+            if transcript_obj["transcript_id"] == gene_obj.get("canonical_transcript"):
+                hgvs_nucleotide = transcript_obj.get("coding_sequence_name") or "-"
+                protein_change = transcript_obj.get("protein_sequence_name") or "-"
         hgvs_c.append(hgvs_nucleotide)
+        pt_c.append(protein_change)
 
-    gene_info.append(";".join(str(x) for x in gene_ids))
-    gene_info.append(";".join(str(x) for x in gene_names))
-    gene_info.append(";".join(str(x) for x in hgvs_c))
+    for item in [gene_ids, gene_names, canonical_txs, hgvs_c, pt_c]:
+        gene_info.append(";".join(str(x) for x in item))
 
     return gene_info
 
@@ -470,9 +541,6 @@ def cancer_variants(store, institute_id, case_name, variants_query, variant_coun
     skip_count = per_page * max(page - 1, 0)
     more_variants = True if variant_count > (skip_count + per_page) else False
 
-    # Setup variant count session with variant count by category
-    variant_count_session(store, institute_id, case_obj["_id"], "clinical", "cancer")
-    session["filtered_variants"] = variant_count
     variant_res = variants_query.skip(skip_count).limit(per_page)
 
     variants_list = []
@@ -494,34 +562,6 @@ def cancer_variants(store, institute_id, case_name, variants_query, variant_coun
     return data
 
 
-def variant_count_session(store, institute_id, case_id, var_type, var_category):
-    """Create a session object containing variant count for each variant category
-
-    Args:
-        store(scout.adapter.MongoAdapter)
-        institute_id(str): Institute ID
-        case_id(str): Case ID
-        var_type(str): "research" or "clinical"
-        var_category(str): "snv", "cancer", "cancer_sv", "sv"
-    """
-    # Run the query just once for a case
-    if (
-        session.get("institute") != institute_id
-        or session.get("case") != case_id
-        or session["case_variants"] is None
-    ):
-        session["case"] = case_id
-        session["institute"] = institute_id
-        case_variants = store.case_variants_count(case_id, institute_id)
-        session["case_variants"] = case_variants
-
-    if session["case_variants"].get(var_type):
-        session["all_variants"] = session["case_variants"][var_type].get(var_category, "NA")
-    else:
-        # Something might always go wrong I guess?
-        session["all_variants"] = "NA"
-
-
 def get_clinvar_submission(store, institute_id, case_name, variant_id, submission_id):
     """Collects all variants from the clinvar submission collection with a specific submission_id
     Args:
@@ -647,6 +687,8 @@ def populate_filters_form(store, institute_obj, case_obj, user_obj, category, re
                 "functional_annotations": SEVERE_SO_TERMS,
             }
         )
+    elif category == "str":
+        FiltersFormClass = StrFiltersForm
 
     if bool(request_form.get("clinical_filter")):
         form = FiltersFormClass(clinical_filter)
@@ -848,6 +890,29 @@ def activate_case(store, institute_obj, case_obj, current_user):
         store.update_status(institute_obj, case_obj, user_obj, "active", case_link)
 
 
+def reset_all_dimissed(store, institute_obj, case_obj):
+    """Reset all dismissed variants for a case.
+
+    Args:
+        store(adapter.MongoAdapter)
+        institute_obj(dict): an institute dictionary
+        case_obj(dict): a case dictionary
+    """
+    evaluated_vars = store.evaluated_variants(case_id=case_obj["_id"])
+    for variant in evaluated_vars:
+        if not variant.get("dismiss_variant"):  # not a dismissed variant
+            continue
+        link_page = "variant.sv_variant" if variant.get("category") == "sv" else "variant.variant"
+        link = url_for(
+            link_page,
+            institute_id=institute_obj["_id"],
+            case_name=case_obj["display_name"],
+            variant_id=variant["_id"],
+        )
+        user = store.user(current_user.email)
+        store.update_dismiss_variant(institute_obj, case_obj, user, link, variant, [])
+
+
 def dismiss_variant_list(store, institute_obj, case_obj, link_page, variants_list, dismiss_reasons):
     """Dismiss a list of variants for a case
 
@@ -857,18 +922,19 @@ def dismiss_variant_list(store, institute_obj, case_obj, link_page, variants_lis
         case_obj(dict): a case dictionary
         link_page(str): "variant.variant" for snvs, "variant.sv_variant" for SVs and so on
         variants_list(list): list of variant._ids (strings)
-        dismiss_reasons(list): list of dismiss options
+        dismiss_reasons(list): list of dismiss options.
     """
     user_obj = store.user(current_user.email)
+    dismiss_reasons = [int(reason) for reason in dismiss_reasons]
     for variant_id in variants_list:
         variant_obj = store.variant(variant_id)
         if variant_obj is None:
             continue
         # create variant link
-        link = link = url_for(
+        link = url_for(
             link_page,
             institute_id=institute_obj["_id"],
-            case_name=case_obj["_id"],
+            case_name=case_obj["display_name"],
             variant_id=variant_id,
         )
         # dismiss variant
