@@ -105,6 +105,12 @@ class VariantFiltersForm(FlaskForm):
     load_filter = SubmitField(label="Load filter")
     delete_filter = SubmitField(label="Delete filter")
 
+    chrom_pos = StringField(
+        "Chromosome position",
+        [validators.Optional()],
+        render_kw={"placeholder": "<chr>:<start pos>-<end pos>[optional +/-<span>]"},
+    )
+
     chrom = SelectField(
         "Chromosome", [validators.Optional()], choices=CHROMOSOME_OPTIONS, default=""
     )
@@ -113,6 +119,7 @@ class VariantFiltersForm(FlaskForm):
     cytoband_start = NonValidatingSelectField("Cytoband start", choices=[])
     cytoband_end = NonValidatingSelectField("Cytoband end", choices=[])
 
+    hide_dismissed = BooleanField("Hide dismissed", default=False)
     filter_variants = SubmitField(label="Filter variants")
     export = SubmitField(label="Filter and export")
 
@@ -125,6 +132,7 @@ class FiltersForm(VariantFiltersForm):
     clinsig_confident_always_returned = BooleanField("CLINSIG Confident")
     spidex_human = SelectMultipleField("SPIDEX", choices=SPIDEX_CHOICES)
     local_obs = IntegerField("Local obs. (archive)")
+
     clinical_filter = SubmitField(label="Clinical filter")
 
 
@@ -142,14 +150,9 @@ class CancerFiltersForm(VariantFiltersForm):
     mvl_tag = BooleanField("In Managed Variant List")
 
 
-class StrFiltersForm(FlaskForm):
+class StrFiltersForm(VariantFiltersForm):
     """docstring for StrFiltersForm"""
 
-    variant_type = HiddenField(default="clinical")
-    chrom = TextField("Chromosome")
-    gene_panels = SelectMultipleField(choices=[])
-    repids = TagListField()
-
 
 class SvFiltersForm(VariantFiltersForm):
     """Extends FiltersForm for structural variants"""
