@@ -16,7 +16,6 @@ from flask import (
     redirect,
     request,
     send_file,
-    session,
     url_for,
 )
 from flask_login import current_user
@@ -45,6 +44,14 @@ variants_bp = Blueprint(
 )
 
 
+@variants_bp.route("/<institute_id>/<case_name>/reset_dismissed", methods=["GET"])
+def reset_dismissed(institute_id, case_name):
+    """Reset all dismissed variants for a case"""
+    institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
+    controllers.reset_all_dimissed(store, institute_obj, case_obj)
+    return redirect(request.referrer)
+
+
 @variants_bp.route("/<institute_id>/<case_name>/variants", methods=["GET", "POST"])
 @templated("variants/variants.html")
 def variants(institute_id, case_name):
@@ -53,13 +60,14 @@ def variants(institute_id, case_name):
     category = "snv"
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
     variant_type = request.args.get("variant_type", "clinical")
+    variants_stats = store.case_variants_count(case_obj["_id"], institute_id, False)
 
     if request.form.get("hpo_clinical_filter"):
         case_obj["hpo_clinical_filter"] = True
 
     user_obj = store.user(current_user.email)
     if request.method == "POST":
-        if request.form.getlist("dismiss"):  # dismiss a list of variants
+        if "dismiss_submit" in request.form:  # dismiss a list of variants
             controllers.dismiss_variant_list(
                 store,
                 institute_obj,
@@ -162,13 +170,11 @@ def variants(institute_id, case_name):
     variants_query = store.variants(case_obj["_id"], query=form.data, category=category)
     result_size = store.count_variants(case_obj["_id"], form.data, None, category)
 
-    # Setup variant count session with variant count by category
-    controllers.variant_count_session(store, institute_id, case_obj["_id"], variant_type, category)
-    session["filtered_variants"] = result_size
     if request.form.get("export"):
         return controllers.download_variants(store, case_obj, variants_query)
 
     data = controllers.variants(store, institute_obj, case_obj, variants_query, result_size, page)
+    expand_search = request.method == "POST" and request.form.get("expand_search") in ["True", ""]
     return dict(
         institute=institute_obj,
         case=case_obj,
@@ -179,25 +185,54 @@ def variants(institute_id, case_name):
         severe_so_terms=SEVERE_SO_TERMS,
         cytobands=cytobands,
         page=page,
-        expand_search=str(request.method == "POST"),
+        expand_search=expand_search,
+        result_size=result_size,
+        total_variants=variants_stats.get(variant_type, {}).get(category, "NA"),
         **data,
     )
 
 
-@variants_bp.route("/<institute_id>/<case_name>/str/variants")
+@variants_bp.route("/<institute_id>/<case_name>/str/variants", methods=["GET", "POST"])
 @templated("variants/str-variants.html")
 def str_variants(institute_id, case_name):
     """Display a list of STR variants."""
-    page = int(request.args.get("page", 1))
+    page = int(request.form.get("page", 1))
     variant_type = request.args.get("variant_type", "clinical")
     category = "str"
 
-    form = StrFiltersForm(request.args)
-
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
+    variants_stats = store.case_variants_count(case_obj["_id"], institute_id, False)
+
+    user_obj = store.user(current_user.email)
+
+    if request.method == "POST":
+        form = controllers.populate_filters_form(
+            store, institute_obj, case_obj, user_obj, category, request.form
+        )
+    else:
+        form = StrFiltersForm(request.args)
+
+        if form.gene_panels.data == [] and variant_type == "clinical":
+            form.gene_panels.data = controllers.case_default_panels(case_obj)
+
+        # set form variant data type the first time around
+        form.variant_type.data = variant_type
+        # set chromosome to all chromosomes
+        form.chrom.data = request.args.get("chrom", "")
+
+    # populate filters dropdown
+    available_filters = store.filters(institute_id, category)
+    form.filters.choices = [
+        (filter.get("_id"), filter.get("display_name")) for filter in available_filters
+    ]
+
+    # populate available panel choices
+    form.gene_panels.choices = controllers.gene_panel_choices(institute_obj, case_obj)
 
     controllers.activate_case(store, institute_obj, case_obj, current_user)
 
+    cytobands = store.cytoband_by_chrom(case_obj.get("genome_build"))
+
     query = form.data
     query["variant_type"] = variant_type
 
@@ -208,7 +243,9 @@ def str_variants(institute_id, case_name):
             ("position", pymongo.ASCENDING),
         ]
     )
-    result_size = store.count_variants(case_obj["_id"], {}, None, category)
+
+    result_size = store.count_variants(case_obj["_id"], query, None, category)
+
     data = controllers.str_variants(
         store, institute_obj, case_obj, variants_query, result_size, page
     )
@@ -218,8 +255,12 @@ def str_variants(institute_id, case_name):
         dismiss_variant_options=DISMISS_VARIANT_OPTIONS,
         variant_type=variant_type,
         manual_rank_options=MANUAL_RANK_OPTIONS,
+        cytobands=cytobands,
         form=form,
         page=page,
+        expand_search=str(request.method == "POST"),
+        result_size=result_size,
+        total_variants=variants_stats.get(variant_type, {}).get(category, "NA"),
         **data,
     )
 
@@ -232,13 +273,14 @@ def sv_variants(institute_id, case_name):
     page = int(request.form.get("page", 1))
     variant_type = request.args.get("variant_type", "clinical")
     category = "sv"
-
     # Define case and institute objects
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
+    variants_stats = store.case_variants_count(case_obj["_id"], institute_id, False)
+
     if request.form.get("hpo_clinical_filter"):
         case_obj["hpo_clinical_filter"] = True
 
-    if request.form.getlist("dismiss"):  # dismiss a list of variants
+    if "dismiss_submit" in request.form:  # dismiss a list of variants
         controllers.dismiss_variant_list(
             store,
             institute_obj,
@@ -255,11 +297,8 @@ def sv_variants(institute_id, case_name):
 
     variants_query = store.variants(case_obj["_id"], category=category, query=form.data)
 
-    # Setup variant count session with variant count by category
-    controllers.variant_count_session(store, institute_id, case_obj["_id"], variant_type, category)
     result_size = store.count_variants(case_obj["_id"], form.data, None, category)
 
-    session["filtered_variants"] = result_size
     # if variants should be exported
     if request.form.get("export"):
         return controllers.download_variants(store, case_obj, variants_query)
@@ -267,7 +306,7 @@ def sv_variants(institute_id, case_name):
     data = controllers.sv_variants(
         store, institute_obj, case_obj, variants_query, result_size, page
     )
-
+    expand_search = request.method == "POST" and request.form.get("expand_search") in ["True", ""]
     return dict(
         institute=institute_obj,
         case=case_obj,
@@ -278,7 +317,9 @@ def sv_variants(institute_id, case_name):
         severe_so_terms=SEVERE_SO_TERMS,
         manual_rank_options=MANUAL_RANK_OPTIONS,
         page=page,
-        expand_search=str(request.method == "POST"),
+        expand_search=expand_search,
+        result_size=result_size,
+        total_variants=variants_stats.get(variant_type, {}).get(category, "NA"),
         **data,
     )
 
@@ -288,12 +329,13 @@ def sv_variants(institute_id, case_name):
 def cancer_variants(institute_id, case_name):
     """Show cancer variants overview."""
     category = "cancer"
-
+    variant_type = request.args.get("variant_type", "clinical")
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
+    variants_stats = store.case_variants_count(case_obj["_id"], institute_id, False)
 
     user_obj = store.user(current_user.email)
     if request.method == "POST":
-        if request.form.getlist("dismiss"):  # dismiss a list of variants
+        if "dismiss_submit" in request.form:  # dismiss a list of variants
             controllers.dismiss_variant_list(
                 store,
                 institute_obj,
@@ -319,7 +361,7 @@ def cancer_variants(institute_id, case_name):
                     ".cancer_variants",
                     institute_id=institute_id,
                     case_name=case_name,
-                    expand_search="True",
+                    expand_search=True,
                 )
             )
         page = int(request.form.get("page", 1))
@@ -345,7 +387,6 @@ def cancer_variants(institute_id, case_name):
 
     cytobands = store.cytoband_by_chrom(case_obj.get("genome_build"))
 
-    variant_type = request.args.get("variant_type", "clinical")
     variants_query = store.variants(case_obj["_id"], category="cancer", query=form.data)
     result_size = store.count_variants(case_obj["_id"], form.data, None, category)
 
@@ -355,7 +396,7 @@ def cancer_variants(institute_id, case_name):
     data = controllers.cancer_variants(
         store, institute_id, case_name, variants_query, result_size, form, page=page
     )
-
+    expand_search = request.method == "POST" and request.form.get("expand_search") in ["True", ""]
     return dict(
         variant_type=variant_type,
         cytobands=cytobands,
@@ -363,7 +404,9 @@ def cancer_variants(institute_id, case_name):
             **DISMISS_VARIANT_OPTIONS,
             **CANCER_SPECIFIC_VARIANT_DISMISS_OPTIONS,
         },
-        expand_search=str(request.method == "POST"),
+        expand_search=expand_search,
+        result_size=result_size,
+        total_variants=variants_stats.get(variant_type, {}).get(category, "NA"),
         **data,
     )
 
@@ -376,23 +419,31 @@ def cancer_sv_variants(institute_id, case_name):
     page = int(request.form.get("page", 1))
     variant_type = request.args.get("variant_type", "clinical")
     category = "cancer_sv"
-
     # Define case and institute objects
     institute_obj, case_obj = institute_and_case(store, institute_id, case_name)
+    variants_stats = store.case_variants_count(case_obj["_id"], institute_id, False)
+
     if request.form.get("hpo_clinical_filter"):
         case_obj["hpo_clinical_filter"] = True
 
+    if request.form.getlist("dismiss"):  # dismiss a list of variants
+        controllers.dismiss_variant_list(
+            store,
+            institute_obj,
+            case_obj,
+            "variant.sv_variant",
+            request.form.getlist("dismiss"),
+            request.form.getlist("dismiss_choices"),
+        )
+
     # update status of case if visited for the first time
     controllers.activate_case(store, institute_obj, case_obj, current_user)
     form = controllers.populate_sv_filters_form(store, institute_obj, case_obj, category, request)
     cytobands = store.cytoband_by_chrom(case_obj.get("genome_build"))
     variants_query = store.variants(case_obj["_id"], category=category, query=form.data)
 
-    # Setup variant count session with variant count by category
-    controllers.variant_count_session(store, institute_id, case_obj["_id"], variant_type, category)
     result_size = store.count_variants(case_obj["_id"], form.data, None, category)
 
-    session["filtered_variants"] = result_size
     # if variants should be exported
     if request.form.get("export"):
         return controllers.download_variants(store, case_obj, variants_query)
@@ -400,7 +451,7 @@ def cancer_sv_variants(institute_id, case_name):
     data = controllers.sv_variants(
         store, institute_obj, case_obj, variants_query, result_size, page
     )
-
+    expand_search = request.method == "POST" and request.form.get("expand_search") in ["True", ""]
     return dict(
         institute=institute_obj,
         case=case_obj,
@@ -415,7 +466,9 @@ def cancer_sv_variants(institute_id, case_name):
         manual_rank_options=MANUAL_RANK_OPTIONS,
         cytobands=cytobands,
         page=page,
-        expand_search=str(request.method == "POST"),
+        expand_search=expand_search,
+        result_size=result_size,
+        total_variants=variants_stats.get(variant_type, {}).get(category, "NA"),
         **data,
     )
 
