@@ -8,9 +8,11 @@ from authlib.integrations.flask_client import OAuth
 from flask_mail import Mail
 
 from scout.adapter import MongoAdapter
+from scout.utils.cloud_resources import AlignTrackHandler
 
 from .loqus_extension import LoqusDB
 from .mongo_extension import MongoDB
+from .gens_extension import GensViewer
 
 
 toolbar = DebugToolbarExtension()
@@ -20,6 +22,7 @@ login_manager = LoginManager()
 ldap_manager = LDAP3LoginManager()
 oauth_client = OAuth()
 mail = Mail()
-
 loqusdb = LoqusDB()
 mongo = MongoDB()
+gens = GensViewer()
+cloud_tracks = AlignTrackHandler()
