@@ -1,6 +1,8 @@
+from flask import current_app
 from pprint import pprint as pp
 
 from scout.constants import SPIDEX_HUMAN
+from scout.utils.convert import amino_acid_residue_change_3_to_1
 
 
 def add_gene_links(gene_obj, build=37):
@@ -56,6 +58,32 @@ def add_gene_links(gene_obj, build=37):
     # Add links that use ucsc link
     gene_obj["ucsc_link"] = ucsc(gene_obj.get("ucsc_id"))
     gene_obj["genemania_link"] = genemania(hgnc_symbol)
+    gene_obj["oncokb_link"] = oncokb(hgnc_symbol)
+    gene_obj["cbioportal_link"] = cbioportal_gene(hgnc_symbol)
+    gene_obj["civic_link"] = civic_gene(hgnc_symbol)
+    gene_obj["iarctp53_link"] = iarctp53(hgnc_symbol)
+
+
+def civic_gene(hgnc_symbol):
+    link = "https://civicdb.org/links/entrez_name/{}"
+
+    if not hgnc_symbol:
+        return None
+    return link.format(hgnc_symbol)
+
+
+def cbioportal_gene(hgnc_symbol):
+    link = "https://www.cbioportal.org/ln?q={}%3AMUT"
+    if not hgnc_symbol:
+        return None
+    return link.format(hgnc_symbol)
+
+
+def oncokb(hgnc_symbol):
+    link = "https://www.oncokb.org/gene/{}"
+    if not hgnc_symbol:
+        return None
+    return link.format(hgnc_symbol)
 
 
 def genemania(hgnc_symbol):
@@ -197,7 +225,7 @@ def ucsc(ucsc_id):
     return link.format(ucsc_id)
 
 
-def add_tx_links(tx_obj, build=37):
+def add_tx_links(tx_obj, build=37, hgnc_symbol=None):
     try:
         build = int(build)
     except ValueError:
@@ -225,6 +253,9 @@ def add_tx_links(tx_obj, build=37):
     tx_obj["varsome_link"] = varsome(
         build, tx_obj.get("refseq_id"), tx_obj.get("coding_sequence_name")
     )
+    tx_obj["tp53_link"] = mutantp53(tx_obj.get("hgnc_id"), tx_obj.get("protein_sequence_name"))
+    tx_obj["cbioportal_link"] = cbioportal(hgnc_symbol, tx_obj.get("protein_sequence_name"))
+    tx_obj["mycancergenome_link"] = mycancergenome(hgnc_symbol, tx_obj.get("protein_sequence_name"))
 
     return tx_obj
 
@@ -302,6 +333,16 @@ def varsome(build, refseq_id, protein_sequence_name):
     return link.format(build, refseq_id, protein_sequence_name)
 
 
+def iarctp53(hgnc_symbol):
+
+    if hgnc_symbol != "TP53":
+        return None
+
+    link = "https://p53.iarc.fr/TP53GeneVariations.aspx"
+
+    return link
+
+
 ############# Variant links ####################
 
 
@@ -327,12 +368,36 @@ def get_variant_links(variant_obj, build=None):
         cosmic_link=cosmic_link(variant_obj),
         beacon_link=beacon_link(variant_obj, build),
         ucsc_link=ucsc_link(variant_obj, build),
+        decipher_link=decipher_link(variant_obj, build),
+        ensembl_link=ensembl_link(variant_obj, build),
         alamut_link=alamut_link(variant_obj, build),
         spidex_human=spidex_human(variant_obj),
+        str_source_link=str_source_link(variant_obj),
     )
     return links
 
 
+def str_source_link(variant_obj):
+    """Compose link for STR data source."""
+
+    if not variant_obj.get("str_source"):
+        return None
+
+    source = variant_obj["str_source"]
+
+    if source["id"] is None:
+        return None
+
+    if source["type"] is None:
+        url_template = "{}"
+    if source["type"] == "GeneReviews":
+        url_template = "https://www.ncbi.nlm.nih.gov/books/{}/"
+    if source["type"] == "PubMed":
+        url_template = "https://pubmed.ncbi.nlm.nih.gov/{}/"
+
+    return url_template.format(source["id"])
+
+
 def thousandg_link(variant_obj, build=None):
     """Compose link to 1000G page for detailed information."""
     dbsnp_id = variant_obj.get("dbsnp_id")
@@ -351,6 +416,34 @@ def thousandg_link(variant_obj, build=None):
     return url_template.format(dbsnp_id)
 
 
+def ensembl_link(variant_obj, build=37):
+    """Compose (sv) variant link to ensembl"""
+
+    my_end = variant_obj["end"]
+    if variant_obj["chromosome"] != variant_obj["end_chrom"]:
+        my_end = variant_obj["position"]
+
+    if build == 37:
+        url_template = "http://grch37.ensembl.org/Homo_sapiens/Location/View?db=core;r={this[chromosome]}:{this[position]}-{my_end}"
+    else:
+        url_template = "http://www.ensembl.org/Homo_sapiens/Location/View?db=core;r={this[chromosome]}:{this[position]}-{my_end}"
+    return url_template.format(this=variant_obj, my_end=my_end)
+
+
+def decipher_link(variant_obj, build=37):
+    """Compose DECIPHER SV variant links"""
+
+    my_end = variant_obj["end"]
+    if variant_obj["chromosome"] != variant_obj["end_chrom"]:
+        my_end = variant_obj["position"]
+
+    if build == 37:
+        url_template = "https://decipher.sanger.ac.uk/search/patients/browser?q=grch37:{this[chromosome]}:{this[position]}-{my_end}"
+    else:
+        url_template = "https://decipher.sanger.ac.uk/browser#q/{this[chromosome]}:{this[position]}-{this[end]}/location/{this[chromosome]}:{this[position]}-{my_end}"
+    return url_template.format(this=variant_obj, my_end=my_end)
+
+
 def exac_link(variant_obj):
     """Compose link to ExAC website for a variant position."""
     url_template = (
@@ -447,7 +540,54 @@ def ucsc_link(variant_obj, build=None):
     return url_template.format(this=variant_obj)
 
 
+def mycancergenome(hgnc_symbol, protein_sequence_name):
+    """Compose link to variant in mycancergenome"""
+    link = "https://www.mycancergenome.org/content/alteration/{}-{}"
+
+    if not hgnc_symbol:
+        return None
+    if not protein_sequence_name:
+        return None
+
+    protein_change = amino_acid_residue_change_3_to_1(protein_sequence_name)
+
+    if not protein_change:
+        return None
+
+    return link.format(hgnc_symbol, protein_change.lower())
+
+
+def cbioportal(hgnc_symbol, protein_sequence_name):
+    """Compose link to variant in cbioportal"""
+    link = "https://www.cbioportal.org/ln?q={}:MUT%20%3D{}"
+
+    if not hgnc_symbol:
+        return None
+    if not protein_sequence_name:
+        return None
+
+    protein_change = amino_acid_residue_change_3_to_1(protein_sequence_name)
+
+    if not protein_change:
+        return None
+
+    return link.format(hgnc_symbol, protein_change)
+
+
+def mutantp53(hgnc_id, protein_variant):
+    """Compose link to variant in mutantp53"""
+    if hgnc_id != 11998:
+        return None
+    if not protein_variant or protein_variant.endswith("=") or protein_variant.endswith("%3D"):
+        return None
+
+    url_template = "http://mutantp53.broadinstitute.org/?query={}"
+
+    return url_template.format(protein_variant)
+
+
 def alamut_link(variant_obj, build=None):
+    """Compose a link which open up variants in the Alamut software"""
     build = build or 37
 
     build_str = ""
@@ -472,3 +612,19 @@ def spidex_human(variant_obj):
         return "medium"
 
     return "high"
+
+
+def external_primer_order_link(variant_obj, build=None):
+    """Compose link for primers orders based on the configuration paramaters EXTERNAL_PRIMER_ORDER_LINK_(37|38)"""
+    build = build or 37
+
+    url_template = ""
+
+    if build == 38:
+        url_template = current_app.config.get("EXTERNAL_PRIMER_ORDER_LINK_38", "")
+    elif build == 37:
+        url_template = current_app.config.get("EXTERNAL_PRIMER_ORDER_LINK_37", "")
+
+    return url_template.format(
+        chromosome=variant_obj.get("chromosome"), position=variant_obj.get("position")
+    )
