@@ -145,7 +145,11 @@ def case_append_alignments(case_obj):
     ]
 
     for individual in case_obj["individuals"]:
-        append_safe(case_obj, "sample_names", individual.get("display_name"))
+        append_safe(
+            case_obj,
+            "sample_names",
+            case_obj["display_name"] + " - " + individual.get("display_name"),
+        )
         for setting in unwrap_settings:
             file_path = individual.get(setting["path"])
             LOG.debug("filepath %s: ", file_path)
