@@ -69,8 +69,12 @@ def test_query_all_gene_variants(real_variant_database):
     gene_variants_query["hgnc_symbols"] = [gene_symbol]
 
     # THEN the same number of variants should be returned by the query function
-    result = adapter.gene_variants(query=gene_variants_query, nr_of_variants=-1)
-    assert sum(1 for i in result) == nr_high_ranked_variants_in_gene
+    result_cursor = adapter.gene_variants(query=gene_variants_query, nr_of_variants=-1)
+    result = sum(1 for i in result_cursor)
+    assert result == nr_high_ranked_variants_in_gene
+
+    # THEN the same number of variants should be returned by 'count_documents'
+    assert result == adapter.count_gene_variants(query=gene_variants_query)
 
 
 def test_load_variants(real_populated_database, variant_objs, case_obj):
