@@ -29,14 +29,18 @@ def test_delete_variants_dry_run(mock_app, case_obj, user_obj):
         "variants",
         "-u",
         user_obj["email"],
-        "-status",
+        "--status",
         "inactive",
-        "-older-than",
+        "--older-than",
         2,
-        "-rank-threshold",
+        "--analysis-type",
+        "wes",
+        "--rank-threshold",
         RANK_THRESHOLD,
-        "-variants-threshold",
+        "--variants-threshold",
         VARIANTS_THRESHOLD,
+        "--keep-ctg",
+        "str",
         "--dry-run",
     ]
     result = runner.invoke(cli, cmd_params)
@@ -66,13 +70,15 @@ def test_delete_variants(mock_app, case_obj, user_obj):
         "variants",
         "-u",
         user_obj["email"],
-        "-status",
+        "--status",
         "inactive",
-        "-older-than",
+        "--older-than",
         2,
-        "-rank-threshold",
+        "--analysis-type",
+        "wes",
+        "--rank-threshold",
         RANK_THRESHOLD,
-        "-variants-threshold",
+        "--variants-threshold",
         VARIANTS_THRESHOLD,
     ]
     result = runner.invoke(cli, cmd_params, input="y")
