@@ -21,6 +21,7 @@ from scout.build.variant import build_variant
 from scout.demo import (
     cancer_load_path,
     cancer_sv_path,
+    cancer_snv_path,
     clinical_snv_path,
     clinical_str_path,
     clinical_sv_path,
@@ -973,6 +974,31 @@ def one_cancer_manta_SV_variant(request, vep_94_manta_annotated_SV_variants_file
     return variant
 
 
+@pytest.fixture(scope="function")
+def one_cancer_variant(request, cancer_snv_file):
+    LOG.info("Return one parsed cancer variant")
+    variant_parser = VCF(cancer_snv_file)
+
+    variant = next(variant_parser)
+    return variant
+
+
+@pytest.fixture(scope="function")
+def parsed_cancer_variant(request, one_cancer_variant, cancer_case_obj):
+    """Return a parsed variant"""
+    variant_dict = parse_variant(one_cancer_variant, cancer_case_obj)
+    return variant_dict
+
+
+@pytest.fixture(scope="function")
+def cancer_variant_obj(request, parsed_cancer_variant):
+    LOG.info("Return one cancer variant obj")
+    institute_id = "cust000"
+
+    variant = build_variant(parsed_cancer_variant, institute_id=institute_id)
+    return variant
+
+
 @pytest.fixture(scope="function")
 def one_variant_customannotation(request, customannotation_snv_file):
     LOG.info("Return one parsed variant with custom annotations")
@@ -1038,6 +1064,14 @@ def parsed_variant(request, one_variant, case_obj):
     return variant_dict
 
 
+@pytest.fixture(scope="function")
+def parsed_str_variant(request, one_str_variant, case_obj):
+    """Return a parsed variant"""
+    print("")
+    variant_dict = parse_variant(one_str_variant, case_obj)
+    return variant_dict
+
+
 @pytest.fixture(scope="function")
 def variant_obj(request, parsed_variant):
     """Return a variant object"""
@@ -1048,9 +1082,17 @@ def variant_obj(request, parsed_variant):
 
 
 @pytest.fixture(scope="function")
-def cyvcf2_variant():
+def str_variant_obj(request, parsed_str_variant):
     """Return a variant object"""
     print("")
+    institute_id = "cust000"
+    variant = build_variant(parsed_str_variant, institute_id=institute_id)
+    return variant
+
+
+@pytest.fixture(scope="function")
+def cyvcf2_variant():
+    """Return a variant object"""
 
     class Cyvcf2Variant(object):
         def __init__(self):
@@ -1283,6 +1325,13 @@ def vep_94_manta_annotated_SV_variants_file(request):
     return cancer_sv_path
 
 
+@pytest.fixture(scope="function")
+def cancer_snv_file(request):
+    """Get the path to a variant file"""
+    print("")
+    return cancer_snv_path
+
+
 @pytest.fixture(scope="function")
 def sv_clinical_file(request):
     """Get the path to a variant file"""
@@ -1468,6 +1517,28 @@ def genemap_handle(request, genemap_file):
     return get_file_handle(genemap_file)
 
 
+#############################################################
+###################### Beacon Fixtures ######################
+#############################################################
+
+
+@pytest.fixture(scope="function")
+def mocked_beacon():
+    """A success response from a mocked Beacon server"""
+
+    class MockBeaconResponse:
+        def __init__(self):
+            self.status_code = 200
+            self.url = "http://beacon_url"
+            self.token = "xyz"
+
+        def json(self):
+            return {"message": "OK"}
+
+    resp = MockBeaconResponse()
+    return resp
+
+
 #############################################################
 #################### MatchMaker Fixtures ####################
 #############################################################
