@@ -1,7 +1,26 @@
 # -*- coding: utf-8 -*-
+import requests
+
 from flask import url_for
 
 
+def test_remote_cors(app):
+    """Test endpoint that servers as a proxy to the actual remote track on the cloud"""
+    cloud_track_url = "http://google.com"
+
+    # GIVEN an initialized app
+    # GIVEN a valid user and institute
+    with app.test_client() as client:
+        # GIVEN that the user could be logged in
+        resp = client.get(url_for("auto_login"))
+        assert resp.status_code == 200
+
+        # WHEN the remote cors endpoint is invoked with an url
+        resp = client.get(url_for("alignviewers.remote_cors", remote_url=cloud_track_url))
+        # THEN it should return success response
+        assert resp.status_code == 200
+
+
 def test_igv(app, user_obj, case_obj):
     """Test view which accepts POST requests and produces igv alignments"""
 
