@@ -1,8 +1,10 @@
 # -*- coding: utf-8 -*-
 import datetime
-from flask import url_for, current_app, get_template_attribute
+import requests
+from flask import url_for, current_app, jsonify
 from flask_login import current_user
-from pymongo import ReturnDocument
+
+from bson.objectid import ObjectId
 
 from scout.demo import delivery_report_path
 from scout.server.blueprints.cases import controllers
@@ -81,86 +83,6 @@ def test_parse_raw_gene_ids(app):
     assert hgnc_ids == {1234, 4321}
 
 
-def test_sidebar_macro(app, institute_obj, case_obj):
-    """test the case sidebar macro"""
-
-    # GIVEN a case with several delivery reports, both in "delivery_report" field and "analyses" field
-    today = datetime.datetime.now()
-    one_year_ago = today - datetime.timedelta(days=365)
-    five_years_ago = today - datetime.timedelta(days=5 * 365)
-    new_report = "new_delivery_report.html"
-    case_analyses = [
-        dict(
-            # fresh analysis from today
-            date=today,
-            delivery_report=new_report,
-        ),
-        dict(
-            # old analysis is 1 year old, missing the report
-            date=one_year_ago,
-            delivery_report=None,
-        ),
-        dict(
-            # ancient analysis is 5 year old
-            date=five_years_ago,
-            delivery_report="ancient_delivery_report.html",
-        ),
-    ]
-    # update test case with the analyses above
-    updated_case = store.case_collection.find_one_and_update(
-        {"_id": case_obj["_id"]},
-        {
-            "$set": {
-                "analysis_date": today,
-                "delivery_report": new_report,
-                "analyses": case_analyses,
-            }
-        },
-        return_document=ReturnDocument.AFTER,
-    )
-
-    # GIVEN an initialized app
-    with app.test_client() as client:
-        # WHEN the case sidebar macro is called
-        macro = get_template_attribute("cases/collapsible_actionbar.html", "action_bar")
-        html = macro(institute_obj, updated_case)
-
-        # It should show the expected items:
-        assert "Reports" in html
-        assert "General" in html
-        assert "mtDNA report" in html
-
-        # only 2 delivery reports should be showed
-        today = str(today).split(" ")[0]
-        assert f"Delivery ({today})" in html
-
-        five_years_ago = str(five_years_ago).split(" ")[0]
-        assert f"Delivery ({five_years_ago})" in html
-
-        # The analysis with missing report should not be shown
-        one_year_ago = str(one_year_ago).split(" ")[0]
-        assert f"Delivery ({one_year_ago})" not in html
-
-        assert f"Genome build {case_obj['genome_build']}" in html
-        assert f"Rank model" in html
-        assert f"Status: {case_obj['status'].capitalize()}" in html
-        assert "Assignees" in html
-        assert "Research list" in html
-        assert "Reruns" in html
-        assert "Share case" in html
-
-
-def test_sidebar_cnv_report(app, institute_obj, cancer_case_obj):
-    # GIVEN an initialized app
-    with app.test_client() as client:
-        # WHEN the case sidebar macro is called
-        macro = get_template_attribute("cases/collapsible_actionbar.html", "action_bar")
-        html = macro(institute_obj, cancer_case_obj)
-
-        # It should show the expected items:
-        assert "CNV report" in html
-
-
 def test_update_cancer_case_sample(app, user_obj, institute_obj, cancer_case_obj):
     # GIVEN an initialized app
     # GIVEN a valid user and institute
@@ -404,6 +326,54 @@ def test_update_case_comment(app, institute_obj, case_obj, user_obj):
         assert updated_var_event["subject"] == updated_comment["subject"]
 
 
+def test_add_case_group(app, case_obj, institute_obj):
+    """Test adding a case group."""
+
+    ### GIVEN an initialized app
+    with app.test_client() as client:
+        # GIVEN that the user could be logged in
+        resp = client.get(url_for("auto_login"))
+
+        # WHEN we invoke the add group endpoint with GET
+        resp = client.get(
+            url_for(
+                "cases.add_case_group",
+                institute_id=institute_obj["_id"],
+                case_name=case_obj["display_name"],
+            )
+        )
+
+        # THEN the response should be a redirect
+        assert resp.status_code == 302
+
+
+def test_remove_case_group(app, case_obj, institute_obj):
+    """Test removing a case group."""
+    ### GIVEN an initialized app
+    group_id = ObjectId("101010101010101010101010")
+    result = store.case_collection.find_one_and_update(
+        {"_id": case_obj["_id"]}, {"$set": {"group": [group_id]}}
+    )
+
+    # GIVEN a valid user and institute
+    with app.test_client() as client:
+        # GIVEN that the user could be logged in
+        resp = client.get(url_for("auto_login"))
+
+        # WHEN we invoke the add group endpoint with GET
+        resp = client.get(
+            url_for(
+                "cases.remove_case_group",
+                institute_id=institute_obj["_id"],
+                case_name=case_obj["display_name"],
+                case_group=group_id,
+            )
+        )
+
+        # THEN the response should be a redirect
+        assert resp.status_code == 302
+
+
 def test_download_hpo_genes(app, case_obj, institute_obj):
     """Test the endpoint that downloads the dynamic gene list for a case"""
 
@@ -554,7 +524,7 @@ def test_matchmaker_matches(app, institute_obj, case_obj, mme_submission, user_o
     store.update_case(case_obj)
 
     res = store.case_collection.find({"mme_submission": {"$exists": True}})
-    assert sum(1 for i in res) == 1
+    assert res
 
     # Monkeypatch response with MME matches
     def mock_matches(*args, **kwargs):
@@ -745,6 +715,30 @@ def test_pdf_delivery_report(app, institute_obj, case_obj, user_obj):
         assert resp.mimetype == "application/pdf"
 
 
+def test_caselist(app, case_obj):
+    """Test the API return of cases for autocompletion"""
+
+    # GIVEN a case
+    # GIVEN an initialized app
+    # GIVEN a valid user and institute
+    with app.test_client() as client:
+        # GIVEN that the user could be logged in
+        resp = client.get(url_for("auto_login"))
+        assert resp.status_code == 200
+
+        # WHEN the API is invoked with a query string containing part of the case term description
+        resp = client.get(
+            url_for(
+                "cases.caselist", institute_id=case_obj["owner"], query=case_obj["display_name"]
+            )
+        )
+        # THEN it should return a valid response
+        assert resp.status_code == 200
+
+        # containing the case display name
+        assert case_obj["display_name"] in str(resp.data)
+
+
 def test_omimterms(app, test_omim_term):
     """Test The API which returns all OMIM terms when queried from case page"""
 
@@ -765,3 +759,106 @@ def test_omimterms(app, test_omim_term):
 
         # containing the OMIM term
         assert test_omim_term["_id"] in str(resp.data)
+
+
+def test_beacon_submit_wrong_config(app, case_obj):
+    """Test saving variants to a Beacon server when Beacon connection parameters are not set"""
+
+    # GIVEN an initialized app
+    with app.test_client() as client:
+        # GIVEN that the user could be logged in
+        resp = client.get(url_for("auto_login"))
+        assert resp.status_code == 200
+
+        form_data = {
+            "case": case_obj["_id"],
+            "samples": "affected",
+            "vcf_files": ["vcf_snv_research", "vcf_snv"],
+        }
+        # WHEN case page is loaded
+        resp = client.post(
+            url_for("cases.beacon_submit"),
+            data=form_data,
+        )
+        # THEN it should redirect to case page
+        assert resp.status_code == 302
+        updated_case = store.case_collection.find_one()
+        # and submission should not be saved in case object
+        assert "beacon" not in updated_case
+
+
+def test_beacon_submit(app, case_obj, monkeypatch, mocked_beacon):
+    """Test submitting variants to a Beacon server"""
+
+    # GIVEN a mocked Beacon server
+    def mock_response(*args, **kwargs):
+        return mocked_beacon
+
+    monkeypatch.setattr(requests, "post", mock_response)
+
+    # GIVEN an initialized app containing the right config settings
+    current_app.config["BEACON_URL"] = mocked_beacon.url
+    current_app.config["BEACON_TOKEN"] = mocked_beacon.token
+
+    with app.test_client() as client:
+        # GIVEN that the user could be logged in
+        resp = client.get(url_for("auto_login"))
+        assert resp.status_code == 200
+
+        form_data = {
+            "case": case_obj["_id"],
+            "samples": "affected",
+            "vcf_files": ["vcf_snv_research", "vcf_snv"],
+        }
+        # WHEN users submits a POST request to Beacon
+        resp = client.post(
+            url_for("cases.beacon_submit"),
+            data=form_data,
+        )
+        # THEN it should redirect to case page
+        assert resp.status_code == 302
+        updated_case = store.case_collection.find_one()
+        # and submissions details should be saved in case object
+        assert "beacon" in updated_case
+        assert updated_case["beacon"]["samples"]
+        assert updated_case["beacon"]["vcf_files"] == form_data["vcf_files"]
+
+
+def test_beacon_remove(app, case_obj, monkeypatch, mocked_beacon):
+    """Test removing variants submitted to Beacon for test case"""
+
+    # GIVEN a mocked Beacon server
+    def mock_response(*args, **kwargs):
+        return mocked_beacon
+
+    monkeypatch.setattr(requests, "post", mock_response)
+
+    # GIVEN a case with variants saved to Beacon
+    store.case_collection.find_one_and_update(
+        {"_id": case_obj["_id"]}, {"$set": {"beacon": {"samples": ["ADM1059A2"]}}}
+    )
+    case_obj = store.case_collection.find_one()
+    assert case_obj["beacon"]
+
+    # GIVEN an initialized app containing the right config settings
+    current_app.config["BEACON_URL"] = mocked_beacon.url
+    current_app.config["BEACON_TOKEN"] = mocked_beacon.token
+
+    with app.test_client() as client:
+        # GIVEN that the user could be logged in
+        resp = client.get(url_for("auto_login"))
+        assert resp.status_code == 200
+
+        # WHEN users submits a GET request to remove data from Beacon
+        resp = client.get(
+            url_for(
+                "cases.beacon_remove",
+                case_id=case_obj["_id"],
+            )
+        )
+        # THEN it should redirect to case page
+        assert resp.status_code == 302
+
+        # And case should no more have an associated Beacon submission
+        updated_case = store.case_collection.find_one()
+        assert "beacon" not in updated_case
