@@ -86,24 +86,23 @@ def test_variants(app, institute_obj, case_obj):
         assert resp.status_code == 200
 
 
-def test_bulk_dismiss_variants(app, institute_obj, case_obj):
-    """Sending a POST request to variants view to test variant dismiss funtionality"""
+def test_bulk_reset_dismiss_variants(app, institute_obj, case_obj):
+    """Test sending a GET request to reset all dismissed variants for a case"""
+
     # GIVEN an initialized app
-    # GIVEN a valid user and institute
     with app.test_client() as client:
         # GIVEN that the user could be logged in
         resp = client.get(url_for("auto_login"))
 
-        # GIVEN a test variant to be dismissed
-        snv_variant = store.variant_collection.find_one({"category": "snv"})
+        variant = store.variant_collection.find_one()
 
-        # When a POST request with filter containing wrongly formatted parameters is sent
-        dismiss_choices = ["2", "5"]
+        # WHEN dismissing a variant using a POST request
+        dismiss_reasons = [3, 5, 7]
         form_data = {
-            "dismiss": snv_variant["_id"],
-            "dismiss_choices": dismiss_choices,
+            "dismiss": variant["_id"],
+            "dismiss_choices": dismiss_reasons,
+            "dismiss_submit": "",
         }
-
         resp = client.post(
             url_for(
                 "variants.variants",
@@ -112,13 +111,28 @@ def test_bulk_dismiss_variants(app, institute_obj, case_obj):
             ),
             data=form_data,
         )
-        # THEN it should return a redirected page
+        # THEN it should return a valid page
         assert resp.status_code == 200
+        # The variant should be updated with the dismissed options
+        updated_variant = store.variant_collection.find_one({"_id": variant["_id"]})
+        assert updated_variant["dismiss_variant"] == dismiss_reasons
 
-        # and the variant should be updated with the dismissed options
-        updated_variant = store.variant_collection.find_one({"_id": snv_variant["_id"]})
-        for option in dismiss_choices:
-            assert option in updated_variant["dismiss_variant"]
+        # When all variants from this case are reset to not dismissed using a GET request to the endpoint
+        resp = client.get(
+            url_for(
+                "variants.reset_dismissed",
+                institute_id=institute_obj["internal_id"],
+                case_name=case_obj["display_name"],
+            ),
+        )
+        # THEN it should return redirect to variants page
+        assert resp.status_code == 302
+        # The variant should NOT be dismissed
+        updated_variant = store.variant_collection.find_one({"_id": variant["_id"]})
+        assert updated_variant.get("dismiss_variant") is None
+
+        # And 2 relative events should be found in the database
+        assert sum(1 for i in store.event_collection.find()) == 2
 
 
 def test_variants_research(app, institute_obj, case_obj):
@@ -346,16 +360,16 @@ def test_sv_cancer_variants(app, institute_obj, case_obj):
         resp = client.get(url_for("auto_login"))
         assert resp.status_code == 200
 
-    # WHEN accessing the sv-variants page
-    resp = client.get(
-        url_for(
-            "variants.cancer_sv_variants",
-            institute_id=institute_obj["internal_id"],
-            case_name=case_obj["display_name"],
+        # WHEN accessing the sv-variants page
+        resp = client.get(
+            url_for(
+                "variants.cancer_sv_variants",
+                institute_id=institute_obj["internal_id"],
+                case_name=case_obj["display_name"],
+            )
         )
-    )
-    # THEN it should return a page
-    assert resp.status_code == 200
+        # THEN it should return a page
+        assert resp.status_code == 200
 
 
 def test_filter_export_cancer_variants(app, institute_obj, case_obj):
