@@ -3,7 +3,6 @@ import logging
 
 import pytest
 import pymongo
-
 from flask import request
 from flask_login import login_user, logout_user
 
@@ -187,145 +186,128 @@ def omim_checkbox():
     return checkbox
 
 
+@pytest.fixture
+def variant_gene_updated_info():
+    """Returns a dictionary with the information from variant gene with updated info, ready to be visualized on the portal"""
+    updated_variant_gene = {
+        "hgnc_id": 30213,
+        "hgnc_symbol": "ATP13A2",
+        "ensembl_id": "ENSG00000159363",
+        "description": "ATPase cation transporting 13A2",
+        "inheritance": ["AR"],
+        "transcripts": [
+            {  # Transcript with refseq_id (and primary)
+                "transcript_id": "ENST00000452699",
+                "hgnc_id": 30213,
+                "protein_id": "ENSP00000413307",
+                "sift_prediction": "deleterious",
+                "polyphen_prediction": "probably_damaging",
+                "swiss_prot": "Q9NQ11",
+                "biotype": "protein_coding",
+                "functional_annotations": ["missense_variant"],
+                "region_annotations": ["exonic"],
+                "exon": "26/29",
+                "strand": "-",
+                "coding_sequence_name": "c.2963C>T",
+                "protein_sequence_name": "p.Pro988Leu",
+                "is_canonical": False,
+                "is_primary": True,
+                "refseq_id": "NM_022089",
+                "refseq_identifiers": ["NM_022089", "NM_001141973"],
+                "ensembl_37_link": "http://grch37.ensembl.org/Homo_sapiens/Gene/Summary?t=ENST00000452699",
+                "ensembl_38_link": "http://ensembl.org/Homo_sapiens/Gene/Summary?t=ENST00000452699",
+                "ensembl_link": "http://grch37.ensembl.org/Homo_sapiens/Gene/Summary?t=ENST00000452699",
+                "refseq_links": [
+                    {"link": "http://www.ncbi.nlm.nih.gov/nuccore/NM_022089", "id": "NM_022089"}
+                ],
+                "swiss_prot_link": "http://www.uniprot.org/uniprot/Q9NQ11",
+                "pfam_domain_link": None,
+                "prosite_profile_link": None,
+                "smart_domain_link": None,
+                "varsome_link": "https://varsome.com/variant/hg37/NM_022089:c.2963C>T",
+                "tp53_link": None,
+                "cbioportal_link": "https://www.cbioportal.org/ln?q=ATP13A2:MUT%20%3DP988L",
+                "mycancergenome_link": "https://www.mycancergenome.org/content/alteration/ATP13A2-p988l",
+                "change_str": "ATP13A2:NM_022089:exon26:c.2963C>T:p.Pro988Leu",
+            },
+            {  # Transcript with NO refseq_id, no primary, no canonical
+                "transcript_id": "NM_001141974.3",
+                "hgnc_id": 30213,
+                "protein_id": "NP_001135446.1",
+                "sift_prediction": "tolerated",
+                "polyphen_prediction": "possibly_damaging",
+                "swiss_prot": "unknown",
+                "biotype": "protein_coding",
+                "functional_annotations": ["missense_variant"],
+                "region_annotations": ["exonic"],
+                "exon": "25/27",
+                "strand": "-",
+                "coding_sequence_name": "c.2846C>T",
+                "protein_sequence_name": "p.Pro949Leu",
+                "is_canonical": False,
+            },
+            {  # Transcript with NO refseq_id, no primary, but canonical
+                "transcript_id": "NM_022089.4",
+                "hgnc_id": 30213,
+                "protein_id": "NP_071372.1",
+                "sift_prediction": "deleterious",
+                "polyphen_prediction": "possibly_damaging",
+                "swiss_prot": "unknown",
+                "biotype": "protein_coding",
+                "functional_annotations": ["missense_variant"],
+                "region_annotations": ["exonic"],
+                "exon": "26/29",
+                "strand": "-",
+                "coding_sequence_name": "c.2978C>T",
+                "protein_sequence_name": "p.Pro993Leu",
+                "is_canonical": True,
+            },
+        ],
+        "functional_annotation": "missense_variant",
+        "region_annotation": "exonic",
+        "sift_prediction": "deleterious",
+        "polyphen_prediction": "possibly_damaging",
+        "hgvs_identifier": "c.2978C>T",
+        "canonical_transcript": "NM_022089.4",
+        "exon": "26/29",
+        "disease_associated_transcripts": [],
+        "manual_penetrance": False,
+        "mosaicism": False,
+        "manual_inheritance": [],
+        "common": {
+            "primary_transcripts": ["NM_022089"],
+        },
+    }
+    return updated_variant_gene
+
+
 @pytest.fixture
 def variant_gene():
     """Returns a dictionary with the information from a variant gene"""
     gene = {
-        "hgnc_id": 10729,
-        "hgnc_symbol": "SEMA4A",
-        "ensembl_id": "ENSG00000196189",
-        "description": "semaphorin 4A",
-        "inheritance": [],
+        "hgnc_id": 30213,
+        "hgnc_symbol": "ATP13A2",
+        "ensembl_id": "ENSG00000159363",
+        "description": "ATPase cation transporting 13A2",
         "transcripts": [
             {
-                "transcript_id": "ENST00000355014",
-                "hgnc_id": 10729,
-                "protein_id": "ENSP00000347117",
-                "sift_prediction": "unknown",
-                "polyphen_prediction": "unknown",
-                "swiss_prot": "Q9H3S1",
+                "transcript_id": "ENST00000452699",
+                "hgnc_id": 30213,
+                "protein_id": "ENSP00000413307",
+                "sift_prediction": "deleterious",
+                "polyphen_prediction": "probably_damaging",
+                "swiss_prot": "Q9NQ11",
                 "biotype": "protein_coding",
-                "functional_annotations": ["intron_variant"],
-                "region_annotations": ["intronic"],
-                "intron": "10/14",
-                "strand": "+",
-                "coding_sequence_name": "c.1135-4554G>A",
-                "is_canonical": False,
-            },
-            {
-                "transcript_id": "ENST00000368282",
-                "hgnc_id": 10729,
-                "protein_id": "ENSP00000357265",
-                "sift_prediction": "unknown",
-                "polyphen_prediction": "unknown",
-                "swiss_prot": "Q9H3S1",
-                "biotype": "protein_coding",
-                "functional_annotations": ["intron_variant"],
-                "region_annotations": ["intronic"],
-                "intron": "9/13",
-                "strand": "+",
-                "coding_sequence_name": "c.1135-4554G>A",
-                "is_canonical": False,
-            },
-            {
-                "transcript_id": "ENST00000368284",
-                "hgnc_id": 10729,
-                "protein_id": "ENSP00000357267",
-                "sift_prediction": "unknown",
-                "polyphen_prediction": "unknown",
-                "swiss_prot": "Q9H3S1",
-                "biotype": "protein_coding",
-                "functional_annotations": ["intron_variant"],
-                "region_annotations": ["intronic"],
-                "intron": "8/12",
-                "strand": "+",
-                "coding_sequence_name": "c.739-4554G>A",
-                "is_canonical": False,
-            },
-            {
-                "transcript_id": "ENST00000368285",
-                "hgnc_id": 10729,
-                "protein_id": "ENSP00000357268",
-                "sift_prediction": "unknown",
-                "polyphen_prediction": "unknown",
-                "swiss_prot": "Q9H3S1",
-                "biotype": "protein_coding",
-                "functional_annotations": ["intron_variant"],
-                "region_annotations": ["intronic"],
-                "intron": "10/14",
-                "strand": "+",
-                "coding_sequence_name": "c.1135-4554G>A",
-                "is_canonical": True,
-            },
-            {
-                "transcript_id": "ENST00000368286",
-                "hgnc_id": 10729,
-                "protein_id": "ENSP00000357269",
-                "sift_prediction": "unknown",
-                "polyphen_prediction": "unknown",
-                "swiss_prot": "Q9H3S1",
-                "biotype": "protein_coding",
-                "functional_annotations": ["intron_variant"],
-                "region_annotations": ["intronic"],
-                "intron": "9/13",
-                "strand": "+",
-                "coding_sequence_name": "c.739-4554G>A",
-                "is_canonical": False,
-            },
-            {
-                "transcript_id": "ENST00000462892",
-                "hgnc_id": 10729,
-                "sift_prediction": "unknown",
-                "polyphen_prediction": "unknown",
-                "swiss_prot": "unknown",
-                "biotype": "retained_intron",
-                "functional_annotations": [
-                    "intron_variant",
-                    "non_coding_transcript_variant",
-                ],
-                "region_annotations": ["intronic", "ncRNA_exonic"],
-                "intron": "2/5",
-                "strand": "+",
-                "coding_sequence_name": "n.444-4554G>A",
-                "is_canonical": False,
-            },
-            {
-                "transcript_id": "ENST00000469065",
-                "hgnc_id": 10729,
-                "sift_prediction": "unknown",
-                "polyphen_prediction": "unknown",
-                "swiss_prot": "unknown",
-                "biotype": "retained_intron",
-                "functional_annotations": ["downstream_gene_variant"],
-                "region_annotations": ["downstream"],
-                "strand": "+",
-                "is_canonical": False,
-            },
-            {
-                "transcript_id": "ENST00000487358",
-                "hgnc_id": 10729,
-                "sift_prediction": "unknown",
-                "polyphen_prediction": "unknown",
-                "swiss_prot": "unknown",
-                "biotype": "processed_transcript",
-                "functional_annotations": [
-                    "intron_variant",
-                    "non_coding_transcript_variant",
-                ],
-                "region_annotations": ["intronic", "ncRNA_exonic"],
-                "intron": "8/10",
-                "strand": "+",
-                "coding_sequence_name": "n.1032-4554G>A",
+                "functional_annotations": ["missense_variant"],
+                "region_annotations": ["exonic"],
+                "exon": "26/29",
+                "strand": "-",
+                "coding_sequence_name": "c.2963C>T",
+                "protein_sequence_name": "p.Pro988Leu",
                 "is_canonical": False,
             },
         ],
-        "functional_annotation": "non_coding_transcript_variant",
-        "region_annotation": "ncRNA_exonic",
-        "sift_prediction": "unknown",
-        "polyphen_prediction": "unknown",
-        "hgvs_identifier": "n.1032-4554G>A",
-        "canonical_transcript": "ENST00000487358",
-        "exon": "",
+        "disease_associated_no_version": set(),
     }
     return gene
 
@@ -334,214 +316,40 @@ def variant_gene():
 def hgnc_gene():
     """docstring for hgnc_gene"""
     gene = {
-        "_id": {"$oid": "5c8112e701f54818d3cbc04a"},
-        "hgnc_id": 10729,
-        "hgnc_symbol": "SEMA4A",
-        "ensembl_id": "ENSG00000196189",
+        "_id": {"$oid": "5fe1dc0ea7dc6a0f011139b1"},
+        "hgnc_id": 30213,
+        "hgnc_symbol": "ATP13A2",
+        "ensembl_id": "ENSG00000159363",
         "chromosome": "1",
-        "start": 156117157,
-        "end": 156147543,
-        "length": 30386,
-        "description": "semaphorin 4A",
-        "aliases": ["SEMA4A", "SEMAB", "CORD10", "SemB", "FLJ12287"],
-        "primary_transcripts": ["NM_022367"],
-        "inheritance_models": ["AD", "AR"],
-        "phenotypes": [
-            {
-                "mim_number": 610283,
-                "description": "Cone-rod dystrophy 10",
-                "inheritance_models": ["AR"],
-                "status": "established",
-            },
-            {
-                "mim_number": 610282,
-                "description": "Retinitis pigmentosa 35",
-                "inheritance_models": ["AD", "AR"],
-                "status": "established",
-            },
-        ],
-        "entrez_id": 64218,
-        "omim_id": 607292,
-        "ucsc_id": "uc001fnl.4",
-        "uniprot_ids": ["Q9H3S1"],
-        "vega_id": "OTTHUMG00000014042",
-        "pli_score": 0.615371620982326,
+        "start": 17312453,
+        "end": 17338423,
+        "length": 25970,
+        "description": "ATPase cation transporting 13A2",
+        "aliases": ["CLN12", "PARK9", "ATP13A2", "HSA9947"],
+        "primary_transcripts": ["NM_022089"],
+        "inheritance_models": ["AR"],
+        "entrez_id": 23400,
+        "omim_id": 610513,
+        "ucsc_id": "uc001baa.3",
+        "uniprot_ids": ["Q9NQ11"],
+        "vega_id": "OTTHUMG00000002293",
+        "pli_score": 0.00120495054739301,
         "incomplete_penetrance": False,
         "build": "37",
         "transcripts": [
             {
-                "_id": {"$oid": "5c81130601f54818d3cc0514"},
-                "ensembl_transcript_id": "ENST00000355014",
-                "hgnc_id": 10729,
+                "_id": {"$oid": "5fe1dc3ea7dc6a0f0111e103"},
+                "ensembl_transcript_id": "ENST00000452699",
+                "hgnc_id": 30213,
                 "chrom": "1",
-                "start": 156119810,
-                "end": 156147535,
-                "is_primary": False,
-                "refseq_id": "NM_001193301",
-                "refseq_identifiers": ["NM_001193301"],
-                "build": "37",
-                "length": 27725,
-            },
-            {
-                "_id": {"$oid": "5c81130601f54818d3cc0516"},
-                "ensembl_transcript_id": "ENST00000368285",
-                "hgnc_id": 10729,
-                "chrom": "1",
-                "start": 156123318,
-                "end": 156147535,
+                "start": 17312453,
+                "end": 17338423,
                 "is_primary": True,
-                "refseq_id": "NM_022367",
-                "refseq_identifiers": ["NM_001193300", "NM_022367", "XM_005245441"],
+                "refseq_id": "NM_022089",
+                "refseq_identifiers": ["NM_022089", "NM_001141973"],
                 "build": "37",
-                "length": 24217,
-            },
-            {
-                "_id": {"$oid": "5c81130601f54818d3cc0517"},
-                "ensembl_transcript_id": "ENST00000368284",
-                "hgnc_id": 10729,
-                "chrom": "1",
-                "start": 156123369,
-                "end": 156147534,
-                "is_primary": False,
-                "refseq_id": "NM_001193302",
-                "refseq_identifiers": ["NM_001193302"],
-                "build": "37",
-                "length": 24165,
-            },
-            {
-                "_id": {"$oid": "5c81130601f54818d3cc0520"},
-                "ensembl_transcript_id": "ENST00000368286",
-                "hgnc_id": 10729,
-                "chrom": "1",
-                "start": 156123388,
-                "end": 156147534,
-                "is_primary": False,
-                "build": "37",
-                "length": 24146,
-            },
-            {
-                "_id": {"$oid": "5c81130601f54818d3cc0519"},
-                "ensembl_transcript_id": "ENST00000368282",
-                "hgnc_id": 10729,
-                "chrom": "1",
-                "start": 156124162,
-                "end": 156147543,
-                "is_primary": False,
-                "refseq_id": "XM_005245442",
-                "refseq_identifiers": ["XM_005245442", "XM_005245444", "XM_005245443"],
-                "build": "37",
-                "length": 23381,
-            },
-            {
-                "_id": {"$oid": "5c81130601f54818d3cc051b"},
-                "ensembl_transcript_id": "ENST00000487358",
-                "hgnc_id": 10729,
-                "chrom": "1",
-                "start": 156126216,
-                "end": 156145023,
-                "is_primary": False,
-                "build": "37",
-                "length": 18807,
-            },
-            {
-                "_id": {"$oid": "5c81130601f54818d3cc051e"},
-                "ensembl_transcript_id": "ENST00000462892",
-                "hgnc_id": 10729,
-                "chrom": "1",
-                "start": 156131018,
-                "end": 156145438,
-                "is_primary": False,
-                "build": "37",
-                "length": 14420,
-            },
-            {
-                "_id": {"$oid": "5c81130601f54818d3cc0512"},
-                "ensembl_transcript_id": "ENST00000435124",
-                "hgnc_id": 10729,
-                "chrom": "1",
-                "start": 156117157,
-                "end": 156131289,
-                "is_primary": False,
-                "build": "37",
-                "length": 14132,
-            },
-            {
-                "_id": {"$oid": "5c81130601f54818d3cc0513"},
-                "ensembl_transcript_id": "ENST00000414683",
-                "hgnc_id": 10729,
-                "chrom": "1",
-                "start": 156119514,
-                "end": 156131284,
-                "is_primary": False,
-                "build": "37",
-                "length": 11770,
-            },
-            {
-                "_id": {"$oid": "5c81130601f54818d3cc0518"},
-                "ensembl_transcript_id": "ENST00000438830",
-                "hgnc_id": 10729,
-                "chrom": "1",
-                "start": 156123398,
-                "end": 156130819,
-                "is_primary": False,
-                "build": "37",
-                "length": 7421,
-            },
-            {
-                "_id": {"$oid": "5c81130601f54818d3cc0515"},
-                "ensembl_transcript_id": "ENST00000485575",
-                "hgnc_id": 10729,
-                "chrom": "1",
-                "start": 156119994,
-                "end": 156126365,
-                "is_primary": False,
-                "build": "37",
-                "length": 6371,
-            },
-            {
-                "_id": {"$oid": "5c81130601f54818d3cc051a"},
-                "ensembl_transcript_id": "ENST00000470306",
-                "hgnc_id": 10729,
-                "chrom": "1",
-                "start": 156124668,
-                "end": 156128822,
-                "is_primary": False,
-                "build": "37",
-                "length": 4154,
-            },
-            {
-                "_id": {"$oid": "5c81130601f54818d3cc051d"},
-                "ensembl_transcript_id": "ENST00000469065",
-                "hgnc_id": 10729,
-                "chrom": "1",
-                "start": 156130741,
-                "end": 156133089,
-                "is_primary": False,
-                "build": "37",
-                "length": 2348,
-            },
-            {
-                "_id": {"$oid": "5c81130601f54818d3cc051f"},
-                "ensembl_transcript_id": "ENST00000484155",
-                "hgnc_id": 10729,
-                "chrom": "1",
-                "start": 156145124,
-                "end": 156146447,
-                "is_primary": False,
-                "build": "37",
-                "length": 1323,
-            },
-            {
-                "_id": {"$oid": "5c81130601f54818d3cc051c"},
-                "ensembl_transcript_id": "ENST00000466698",
-                "hgnc_id": 10729,
-                "chrom": "1",
-                "start": 156130335,
-                "end": 156131460,
-                "is_primary": False,
-                "build": "37",
-                "length": 1125,
-            },
+                "length": 25970,
+            }
         ],
     }
     return gene
