@@ -1,6 +1,6 @@
 """Tests for scout server links"""
 
-from scout.server.links import add_gene_links
+from scout.server.links import add_gene_links, cbioportal, mycancergenome
 
 
 def test_add_gene_links():
@@ -35,3 +35,21 @@ def test_ucsc_link():
     # THEN assert some links are added
     link = gene_obj.get("ucsc_link")
     assert link is not None
+
+
+def test_cbioportal_link():
+    """Test if CBioPortal link is made correctly"""
+
+    hgnc_symbol = "TP53"
+    protein_change = "p.Ser241Phe"
+
+    link = cbioportal(hgnc_symbol, protein_change)
+    assert link is not None
+
+
+def test_mycancergenome_link():
+    hgnc_symbol = "TP53"
+    protein_change = "p.Ser241Phe"
+
+    link = mycancergenome(hgnc_symbol, protein_change)
+    assert link is not None
